--- This migration is a rollup of all previous migrations.  It attempts to determine     ---
--- which of the previous migrations have been completed and only apply the missing      ---
--- updates.  This cumulative migration moves the db schema version to 314 from versions ---
--- 4 or lower.                                                                          ---
--- 10/21/2008 eshoemaker                                                                ---




----------------------------------------------------------------
-- dbmigrate0
----------------------------------------------------------------
CREATE OR REPLACE FUNCTION dbmigrate0() RETURNS bool AS $$
BEGIN

	CREATE TABLE db_version (version integer not null);	
	INSERT INTO db_version VALUES (1);

	RETURN TRUE;

EXCEPTION

	WHEN syntax_error_or_access_rule_violation THEN
		RAISE NOTICE 'Exception in dbmigrate0.  This migration has already been performed ';
		RETURN FALSE;

END;
$$ LANGUAGE plpgsql;

----------------------------------------------------------------
-- dbmigrate1
----------------------------------------------------------------
CREATE OR REPLACE FUNCTION dbmigrate1() RETURNS bool AS $$
BEGIN

	-- This SQL script creates the required tables by org.apache.log4j.db.DBAppender and
	-- org.apache.log4j.db.DBReceiver.
	--
	-- It is intended for PostgreSQL databases.

	-- DROP TABLE    logging_event_property;
	-- DROP TABLE    logging_event_exception;
	-- DROP TABLE    logging_event;
	-- DROP SEQUENCE logging_event_id_seq;

	CREATE SEQUENCE logging_event_id_seq MINVALUE 1 START 1;

	CREATE TABLE logging_event
	  (
	    sequence_number   BIGINT NOT NULL,
	    timestamp         BIGINT NOT NULL,
	    rendered_message  TEXT NOT NULL,
	    logger_name       VARCHAR(254) NOT NULL,
	    level_string      VARCHAR(254) NOT NULL,
	    ndc               TEXT,
	    thread_name       VARCHAR(254),
	    reference_flag    SMALLINT,
	    caller_filename   VARCHAR(254) NOT NULL,
	    caller_class      VARCHAR(254) NOT NULL,
	    caller_method     VARCHAR(254) NOT NULL,
	    caller_line       CHAR(4) NOT NULL,
	    event_id          INT DEFAULT nextval('logging_event_id_seq') PRIMARY KEY
	  );

	CREATE TABLE logging_event_property
	  (
	    event_id          INT NOT NULL,
	    mapped_key        VARCHAR(254) NOT NULL,
	    mapped_value      VARCHAR(1024),
	    PRIMARY KEY(event_id, mapped_key),
	    FOREIGN KEY (event_id) REFERENCES logging_event(event_id)
	  );

	CREATE TABLE logging_event_exception
	  (
	    event_id         INT NOT NULL,
	    i                SMALLINT NOT NULL,
	    trace_line       VARCHAR(254) NOT NULL,
	    PRIMARY KEY(event_id, i),
	    FOREIGN KEY (event_id) REFERENCES logging_event(event_id)
	  );

	GRANT ALL ON TABLE logging_event TO "wikid-sens";
	GRANT ALL ON TABLE logging_event_exception TO "wikid-sens";
	GRANT ALL ON TABLE logging_event_property TO "wikid-sens";

	RETURN TRUE;

EXCEPTION

	WHEN syntax_error_or_access_rule_violation THEN
		RAISE NOTICE 'Exception in dbmigrate1.   This migration has already been performed ';
		RETURN FALSE;


END;
$$ LANGUAGE plpgsql;
 



----------------------------------------------------------------
-- dbmigrate2
----------------------------------------------------------------
CREATE OR REPLACE FUNCTION dbmigrate2() RETURNS bool AS $$
BEGIN


	-- Upgrade from the 3.0.3 schema to 3

	ALTER TABLE full_domain
	   ADD COLUMN lockrequired boolean DEFAULT false;


	ALTER TABLE full_devices
	   ADD COLUMN lockcode character(50);


	DROP VIEW devices CASCADE;

	CREATE VIEW devices AS
	    SELECT full_devices.id_devices, full_devices.deviceid, full_devices.ckey, full_devices.lockcode, full_devices.id_cryptotype, full_devices.init_expire, full_devices.creation FROM full_devices WHERE (full_devices.deleted = false);
	ALTER TABLE devices ALTER COLUMN id_devices SET DEFAULT nextval('"devices_id_devices_seq"'::text);
	ALTER TABLE devices ALTER COLUMN creation SET DEFAULT now();


	REVOKE ALL ON TABLE devices FROM PUBLIC;
	GRANT SELECT,UPDATE,DELETE ON TABLE devices TO wikidncserver;
	GRANT SELECT,UPDATE,DELETE ON TABLE devices TO timecop;
	GRANT ALL ON TABLE devices TO wikidadmin;


	-- insert rule moved outside function due to pl/pgsql parser bug

	CREATE RULE devices_update_rule AS ON UPDATE TO devices DO INSTEAD UPDATE full_devices SET id_devices = new.id_devices, deviceid = new.deviceid, ckey = new.ckey, id_cryptotype = new.id_cryptotype, lockcode = new.lockcode, init_expire = new.init_expire, creation = new.creation WHERE (full_devices.id_devices = old.id_devices);


	CREATE RULE devices_delete_rule AS ON DELETE TO devices DO INSTEAD UPDATE full_devices SET deleted = true WHERE (full_devices.id_devices = old.id_devices);

	RETURN TRUE;

EXCEPTION

	WHEN syntax_error_or_access_rule_violation THEN
		RAISE NOTICE 'Exception in dbmigrate2.   This migration has already been performed ';
		RETURN FALSE;


END;
$$ LANGUAGE plpgsql;




----------------------------------------------------------------
-- dbmigrate3
----------------------------------------------------------------
CREATE OR REPLACE FUNCTION dbmigrate3() RETURNS bool AS $$
BEGIN

	-- Add support for SAML 1.1


	ALTER TABLE full_domain
	   ADD COLUMN use_saml integer NOT NULL DEFAULT 0, 
	   ADD COLUMN saml_idp_url character varying(256), 
	   ADD COLUMN saml_assertion_timelimit integer;


	CREATE TABLE saml_consumers
	(
		id serial,
		service_url character varying(256), 
		p_name_target character varying(256), 
		p_name_artifact  character varying(256),
		target_url character varying(256)
	);

	CREATE TABLE saml_sessions 
	(
		id serial,
		created_at timestamp DEFAULT NOW(),
		artifact TEXT, 
		id_user integer, 
		expired_at timestamp, 
		consumer_id integer, 
		subject_ip character varying(255)
	);



	RETURN TRUE;

EXCEPTION

	WHEN syntax_error_or_access_rule_violation THEN
		RAISE NOTICE 'Exception in dbmigrate3.   This migration has already been performed ';
		RETURN FALSE;


END;
$$ LANGUAGE plpgsql;



----------------------------------------------------------------
-- dbmigrate4
----------------------------------------------------------------

-- Add support for the SHA256 message digest
CREATE OR REPLACE FUNCTION dbmigrate4() RETURNS bool AS $$
BEGIN

	ALTER TABLE tempregcodes
	   ADD COLUMN regcode256 character varying(40);

	-- Patch a permissions issue with Tacacs

	GRANT SELECT ON TABLE network_client TO timecop;
	GRANT SELECT ON TABLE host_nc_map TO timecop;
	GRANT SELECT ON TABLE host TO timecop;

	RETURN TRUE;

EXCEPTION

	WHEN syntax_error_or_access_rule_violation THEN
		RAISE NOTICE 'Exception in dbmigrate4.   This migration has already been performed ';
		RETURN FALSE;


END;
$$ LANGUAGE plpgsql;


----------------------------------------------------------------
-- dbmigrate5
----------------------------------------------------------------

-- Add support for restricting to certain token clients only
CREATE OR REPLACE FUNCTION dbmigrate5() RETURNS bool AS $$
BEGIN

	ALTER TABLE full_domain
	   ADD COLUMN clients_allowed bigint NOT NULL DEFAULT 0;

	RETURN TRUE;

EXCEPTION

	WHEN syntax_error_or_access_rule_violation THEN
		RAISE NOTICE 'Exception in dbmigrate5.   This migration has already been performed ';
		RETURN FALSE;


END;
$$ LANGUAGE plpgsql;


----------------------------------------------------------------
-- dbmigrate6
----------------------------------------------------------------

-- roll up the migration of the domain view and rules
CREATE OR REPLACE FUNCTION dbmigrate6() RETURNS bool AS $$
BEGIN

	DROP VIEW "domain" CASCADE;


	CREATE VIEW "domain" AS
			SELECT full_domain.id_domain, full_domain.code, full_domain.name, full_domain.ddname, full_domain.registered_url, full_domain.registered_url_hash, full_domain.minpin, full_domain."valid", full_domain.maxbads, full_domain.maxoffs, full_domain.maxattempts, full_domain.publickey, full_domain.privatekey, full_domain.creation, full_domain.reset_domain, full_domain.nt_host, full_domain.admin_user, full_domain.admin_passwd, full_domain.nt_domain_name, full_domain.tacacs, full_domain.lockrequired, full_domain.clients_allowed, full_domain.use_saml, full_domain.saml_idp_url, full_domain.saml_assertion_timelimit FROM full_domain WHERE ((full_domain.deleted = false) AND (full_domain.id_domain > 0));
	ALTER TABLE "domain" ALTER COLUMN id_domain SET DEFAULT nextval('"domain_id_domain_seq"'::text);
	ALTER TABLE "domain" ALTER COLUMN maxattempts SET DEFAULT 0;
	ALTER TABLE "domain" ALTER COLUMN creation SET DEFAULT now();


	REVOKE ALL ON TABLE "domain" FROM PUBLIC;
	GRANT SELECT ON TABLE "domain" TO wikidncserver;
	GRANT ALL ON TABLE "domain" TO wikidadmin;


	-- insert rule moved outside function due to pl/pgsql parser bug


	CREATE OR REPLACE RULE domain_update_rule AS ON UPDATE TO "domain" DO INSTEAD UPDATE full_domain SET id_domain = new.id_domain, code = new.code, name = new.name, ddname = new.ddname, registered_url = new.registered_url, registered_url_hash = new.registered_url_hash, minpin = new.minpin, "valid" = new."valid", maxbads = new.maxbads, maxoffs = new.maxoffs, lockrequired = new.lockrequired, clients_allowed = new.clients_allowed, use_saml = 0, saml_idp_url = new.saml_idp_url, saml_assertion_timelimit = new.saml_assertion_timelimit, tacacs = new.tacacs, maxattempts = new.maxattempts, publickey = new.publickey, privatekey = new.privatekey, creation = new.creation, reset_domain = new.reset_domain, nt_host = new.nt_host, admin_user = new.admin_user, admin_passwd = new.admin_passwd, nt_domain_name = new.nt_domain_name WHERE (full_domain.id_domain = old.id_domain);


	CREATE OR REPLACE RULE domain_delete_rule AS ON DELETE TO "domain" DO INSTEAD UPDATE full_domain SET deleted = true WHERE (full_domain.id_domain = old.id_domain);


	CREATE OR REPLACE VIEW radius_nc_view AS 
	 SELECT host.id_host, domain.code AS domain, host_nc_map.host, host_nc_map.nc, network_client.id_nc, network_client.name, network_client.ip, network_client.secret, network_client.enforced, network_client.domain AS nc_domain
	   FROM host_nc_map, network_client, host, domain
	  WHERE network_client.domain = domain.id_domain AND host.id_host = host_nc_map.host AND network_client.id_nc = host_nc_map.nc AND host.type = 1;

	ALTER TABLE radius_nc_view OWNER TO postgres;
	GRANT ALL ON TABLE radius_nc_view TO postgres;
	GRANT ALL ON TABLE radius_nc_view TO "wikid-sens";


	CREATE OR REPLACE VIEW usr_dev_dom AS 
	 SELECT usermap.userid, devicemap.deviceid, domain.code, domain.ddname, usermap.id_usermap, devicemap.id_devicemap, domain.id_domain
	   FROM usermap, devicemap, domain
	  WHERE usermap.id_devicemap = devicemap.id_devicemap AND domain.id_domain = devicemap.domainid;

	ALTER TABLE usr_dev_dom OWNER TO postgres;
	GRANT ALL ON TABLE usr_dev_dom TO postgres;
	GRANT ALL ON TABLE usr_dev_dom TO "wikid-sens";
    RETURN TRUE;

EXCEPTION

	WHEN syntax_error_or_access_rule_violation THEN
		RAISE NOTICE 'Exception in dbmigrate6.   This migration has already been performed ';
		RETURN FALSE;

END;
$$ LANGUAGE plpgsql;


----------------------------------------------------------------
-- dbmigrate7
----------------------------------------------------------------

-- add support for pre=registration and embedded registration ids
CREATE OR REPLACE FUNCTION dbmigrate7() RETURNS bool AS $$
BEGIN

    -- Support embedded ids for token registration
    ALTER TABLE tempregcodes ADD COLUMN embedded_id character varying(50);


    -- Add tables for pre-registration support
    CREATE SEQUENCE id_pre_registration_seq
      INCREMENT 1
      MINVALUE 1
      MAXVALUE 9223372036854775807
      START 3
      CACHE 1;
    ALTER TABLE id_pre_registration_seq OWNER TO postgres;
    GRANT ALL ON TABLE id_pre_registration_seq TO postgres;
    GRANT ALL ON TABLE id_pre_registration_seq TO wikidncserver;

    CREATE TABLE pre_registration
    (
      id_pre_registration bigint NOT NULL DEFAULT nextval(('"id_pre_registration_seq"'::text)::regclass),
      id_usermap bigint DEFAULT (-1),
      temp_name character varying(255) NOT NULL,
      pre_registration_code character(25) NOT NULL,
      email_address character varying(255) NOT NULL,
      CONSTRAINT pk_pre_registration PRIMARY KEY (id_pre_registration)
    );
    ALTER TABLE pre_registration OWNER TO postgres;
    GRANT ALL ON TABLE pre_registration TO postgres;
    GRANT ALL ON TABLE pre_registration TO wikidncserver;
    GRANT ALL ON TABLE pre_registration TO wikidadmin;


    CREATE UNIQUE INDEX "pre_registration_code_ndx"
      ON pre_registration
      USING btree
      (pre_registration_code);

    RETURN TRUE;

EXCEPTION

	WHEN syntax_error_or_access_rule_violation THEN
		RAISE NOTICE 'Exception in dbmigrate7.   This migration has already been performed ';
		RETURN FALSE;


END;
$$ LANGUAGE plpgsql;

----


----------------------------------------------------------------
-- dbmigrate8
----------------------------------------------------------------

-- add creation date to the pre-registration data
CREATE OR REPLACE FUNCTION dbmigrate8() RETURNS bool AS $$
BEGIN

    -- add creation column
    ALTER TABLE pre_registration ADD COLUMN creation bigint NOT NULL default (-1);

    -- disable registration expiration
    update devices set init_expire=('now' + '6500 days'::reltime) where init_expire > ('now' + '5 days'::reltime);
    update devicemap set init_expire=('now' + '6500 days'::reltime) where init_expire > ('now' + '5 days'::reltime);

    -- drop unique constraint on pre-registration codes
    DROP INDEX "pre_registration_code_ndx";

    -- remove deprecated parameters
    delete from parms1to1 where key='EnableSyslog';
    delete from parms1to1 where key='SyslogHost';

    RETURN TRUE;

EXCEPTION

	WHEN syntax_error_or_access_rule_violation THEN
		RAISE NOTICE 'Exception in dbmigrate8.   This migration has already been performed ';
		RETURN FALSE;


END;
$$ LANGUAGE plpgsql;

----

----------------------------------------------------------------
-- dbmigrate9
----------------------------------------------------------------

-- add group tables
CREATE OR REPLACE FUNCTION dbmigrate9() RETURNS bool AS $$
BEGIN

        CREATE SEQUENCE id_group_radius_attrib_seq
          INCREMENT 1
          MINVALUE 1
          MAXVALUE 9223372036854775807
          START 12
          CACHE 1;
        ALTER TABLE id_group_radius_attrib_seq OWNER TO postgres;
        GRANT ALL ON TABLE id_group_radius_attrib_seq TO postgres;
        GRANT ALL ON TABLE id_group_radius_attrib_seq TO public;
                    

        CREATE SEQUENCE id_user_group_map_seq
          INCREMENT 1
          MINVALUE 1
          MAXVALUE 9223372036854775807
          START 5
          CACHE 1;
        ALTER TABLE id_user_group_map_seq OWNER TO postgres;
        GRANT ALL ON TABLE id_user_group_map_seq TO postgres;
        GRANT ALL ON TABLE id_user_group_map_seq TO public;

        CREATE SEQUENCE id_wikid_group_seq
          INCREMENT 1
          MINVALUE 1
          MAXVALUE 9223372036854775807
          START 8
          CACHE 1;
        ALTER TABLE id_wikid_group_seq OWNER TO postgres;
        GRANT ALL ON TABLE id_wikid_group_seq TO postgres;
        GRANT ALL ON TABLE id_wikid_group_seq TO public;


        CREATE TABLE wikid_group
        (
          id_wikid_group bigint NOT NULL DEFAULT nextval(('"id_wikid_group_seq"'::text)::regclass),
          group_name character varying(255) NOT NULL,
          CONSTRAINT wikid_group_pk PRIMARY KEY (id_wikid_group)
        );
        ALTER TABLE wikid_group OWNER TO postgres;
        GRANT ALL ON TABLE wikid_group TO postgres;
        GRANT ALL ON TABLE wikid_group TO public;

        CREATE TABLE user_group_map
        (
          id_user_group_map bigint NOT NULL DEFAULT nextval(('"id_user_group_map_seq"'::text)::regclass),
          id_usermap bigint NOT NULL,
          id_wikid_group bigint NOT NULL,
          CONSTRAINT id_user_group_map_pk PRIMARY KEY (id_user_group_map)
        );
        ALTER TABLE user_group_map OWNER TO postgres;
        GRANT ALL ON TABLE user_group_map TO postgres;
        GRANT ALL ON TABLE user_group_map TO public;

        CREATE TABLE group_radius_attrib
        (
          id_group_radius_attrib bigint NOT NULL DEFAULT nextval(('"id_group_radius_attrib_seq"'::text)::regclass),
          id_wikid_group bigint NOT NULL,
          akey character(100) NOT NULL,
          avalue character varying(255) NOT NULL,
          CONSTRAINT id_group_radius_attrib_pk PRIMARY KEY (id_group_radius_attrib),
          CONSTRAINT "$1" FOREIGN KEY (id_wikid_group)
              REFERENCES wikid_group (id_wikid_group) MATCH SIMPLE
              ON UPDATE NO ACTION ON DELETE NO ACTION
        );
        ALTER TABLE group_radius_attrib OWNER TO postgres;
        GRANT ALL ON TABLE group_radius_attrib TO postgres;
        GRANT ALL ON TABLE group_radius_attrib TO public;

        RETURN TRUE;


EXCEPTION

	WHEN syntax_error_or_access_rule_violation THEN
		RAISE NOTICE 'Exception in dbmigrate9.   This migration has already been performed ';
		RETURN FALSE;


END;
$$ LANGUAGE plpgsql;

----


----------------------------------------------------------------
-- dbmigrate10
----------------------------------------------------------------

-- fix rights problem
CREATE OR REPLACE FUNCTION dbmigrate10() RETURNS bool AS $$
BEGIN

	GRANT ALL ON TABLE id_pre_registration_seq TO public;
        RETURN TRUE;


EXCEPTION

	WHEN syntax_error_or_access_rule_violation THEN
		RAISE NOTICE 'Exception in dbmigrate10.   This migration has already been performed ';
		RETURN FALSE;


END;
$$ LANGUAGE plpgsql;

----


----------------------------------------------------------------
-- dbmigrate11
----------------------------------------------------------------

-- Add support for Google SSO
CREATE OR REPLACE FUNCTION dbmigrate11() RETURNS bool AS $$
BEGIN

  -- Insert the new protocol module type into the database
    INSERT INTO host_type ("type", "name") values (4, 'GoogleSSO');

  -- Create the table for the Google app to domain relation
    CREATE SEQUENCE id_gsso_app_domain_map_seq
      INCREMENT 1
      MINVALUE 1
      MAXVALUE 9223372036854775807
      START 5
      CACHE 1;
    ALTER TABLE id_gsso_app_domain_map_seq OWNER TO postgres;
    GRANT ALL ON TABLE id_gsso_app_domain_map_seq TO postgres;
    GRANT ALL ON TABLE id_gsso_app_domain_map_seq TO public;

    CREATE TABLE gsso_app_domain_map
    (
      id_gsso_app_domain_map bigint NOT NULL DEFAULT nextval(('"id_gsso_app_domain_map_seq"'::text)::regclass),
      id_nc bigint NOT NULL,
      acs_url character varying(255) NOT NULL,
      CONSTRAINT id_gsso_app_domain_map_pk PRIMARY KEY (id_gsso_app_domain_map)
    );
    ALTER TABLE gsso_app_domain_map OWNER TO postgres;
    GRANT ALL ON TABLE gsso_app_domain_map TO postgres;
    GRANT ALL ON TABLE gsso_app_domain_map TO public;



  RETURN TRUE;
EXCEPTION
	WHEN syntax_error_or_access_rule_violation THEN
		RAISE NOTICE 'Exception in dbmigrate11.   This migration may have already been performed ';
		RETURN FALSE;
	WHEN integrity_constraint_violation THEN
		RAISE NOTICE 'Exception in dbmigrate11.   This migration may have already been performed ';
		RETURN FALSE;
END;
$$ LANGUAGE plpgsql;

----

----------------------------------------------------------------
-- dbmigrate12
----------------------------------------------------------------

-- add vendor radius attributes
CREATE OR REPLACE FUNCTION dbmigrate12() RETURNS bool AS $$
BEGIN

    ALTER TABLE group_radius_attrib ADD COLUMN vendor_id integer;

  RETURN TRUE;
EXCEPTION

	WHEN syntax_error_or_access_rule_violation THEN
		RAISE NOTICE 'Exception in dbmigrate12.   This migration has already been performed ';
		RETURN FALSE;

END;
$$ LANGUAGE plpgsql;

----

----------------------------------------------------------------
-- dbmigrate13
----------------------------------------------------------------

-- fix a schema bug related to embedded registration ids for a certain release
CREATE OR REPLACE FUNCTION dbmigrate13() RETURNS bool AS $$
BEGIN

    -- Support embedded ids for token registration
    ALTER TABLE tempregcodes ADD COLUMN embedded_id character varying(50);

    RETURN TRUE;

EXCEPTION

	WHEN syntax_error_or_access_rule_violation THEN
		RAISE NOTICE 'dbmigrate13:   This migration has already been performed ';
		RETURN FALSE;


END;
$$ LANGUAGE plpgsql;

----

----------------------------------------------------------------
-- dbmigrate14
----------------------------------------------------------------

-- fix a schema bug related to embedded registration ids for a certain release
CREATE OR REPLACE FUNCTION dbmigrate14() RETURNS bool AS $$
BEGIN

    -- Support embedded ids for token registration
    CREATE UNIQUE INDEX unique_type ON host_type USING btree (type);

    RETURN TRUE;

EXCEPTION

	WHEN syntax_error_or_access_rule_violation THEN
		RAISE NOTICE 'dbmigrate14:   This migration has already been performed ';
		RETURN FALSE;


END;
$$ LANGUAGE plpgsql;

----

----------------------------------------------------------------
-- dbmigrate15
----------------------------------------------------------------

-- Add the domain to pre-registrations
CREATE OR REPLACE FUNCTION dbmigrate15() RETURNS bool AS $$
BEGIN

    -- Add column for id_domain
    ALTER TABLE pre_registration ADD COLUMN id_domain bigint NOT NULL DEFAULT -1;

    RETURN TRUE;

EXCEPTION

	WHEN syntax_error_or_access_rule_violation THEN
		RAISE NOTICE 'dbmigrate15:   This migration has already been performed ';
		RETURN FALSE;


END;
$$ LANGUAGE plpgsql;

----

----------------------------------------------------------------
-- dbmigrate16
----------------------------------------------------------------

-- Add the domain to pre-registrations
CREATE OR REPLACE FUNCTION dbmigrate16() RETURNS bool AS $$
BEGIN

    -- Add column for id_domain
    ALTER TABLE wikid_group ADD COLUMN precedence integer NOT NULL DEFAULT -1;

    RETURN TRUE;

EXCEPTION

	WHEN syntax_error_or_access_rule_violation THEN
		RAISE NOTICE 'dbmigrate16:   This migration has already been performed ';
		RETURN FALSE;


END;
$$ LANGUAGE plpgsql;

----

----------------------------------------------------------------
-- dbmigrate17
----------------------------------------------------------------

CREATE OR REPLACE FUNCTION dbmigrate17() RETURNS bool AS $$
BEGIN

	ALTER TABLE full_devices ADD COLUMN client_type integer NOT NULL DEFAULT 0;
	ALTER TABLE full_devices ADD COLUMN last_activity date;
	ALTER TABLE full_usermap ADD COLUMN note character varying(50);
	ALTER TABLE full_usermap ADD COLUMN last_activity date;

	DROP VIEW devices;
	
	CREATE OR REPLACE VIEW devices AS
	SELECT full_devices.id_devices, full_devices.deviceid, full_devices.ckey, full_devices.lockcode, full_devices.id_cryptotype, full_devices.init_expire, full_devices.creation, full_devices.client_type, full_devices.last_activity
	   FROM full_devices
	  WHERE full_devices.deleted = false;

	ALTER TABLE devices ALTER COLUMN id_devices SET DEFAULT nextval('"devices_id_devices_seq"'::text);
    ALTER TABLE devices ALTER COLUMN creation SET DEFAULT now();

    REVOKE ALL ON TABLE devices FROM PUBLIC;
    REVOKE ALL ON TABLE devices FROM postgres;
    GRANT ALL ON TABLE devices TO postgres;
    GRANT SELECT,UPDATE,DELETE ON TABLE devices TO wikidncserver;
    GRANT SELECT,UPDATE,DELETE ON TABLE devices TO timecop;
    GRANT ALL ON TABLE devices TO wikidadmin;

	
	CREATE OR REPLACE RULE devices_insert_rule AS
	    ON INSERT TO devices DO INSTEAD  INSERT INTO full_devices (id_devices, deviceid, ckey, id_cryptotype, lockcode, init_expire, creation, client_type, last_activity, deleted) 
	  VALUES (new.id_devices, new.deviceid, new.ckey, new.id_cryptotype, new.lockcode, new.init_expire, new.creation, new.client_type, new.last_activity, false);
	
	CREATE OR REPLACE RULE devices_update_rule AS
	    ON UPDATE TO devices DO INSTEAD  UPDATE full_devices SET id_devices = new.id_devices, deviceid = new.deviceid, ckey = new.ckey, id_cryptotype = new.id_cryptotype, lockcode = new.lockcode, init_expire = new.init_expire, creation = new.creation, client_type = new.client_type, last_activity = new.last_activity
	  WHERE full_devices.id_devices = old.id_devices;

	CREATE OR REPLACE RULE devices_delete_rule AS ON DELETE TO devices DO INSTEAD UPDATE full_devices SET deleted = true WHERE (full_devices.id_devices = old.id_devices);


	DROP VIEW usermap CASCADE;
	
	CREATE OR REPLACE VIEW usermap AS
	SELECT full_usermap.id_usermap, full_usermap.id_devicemap, full_usermap.userid, full_usermap.bads, full_usermap.creation, full_usermap.status, full_usermap.note, full_usermap.last_activity
	   FROM full_usermap
	  WHERE full_usermap.deleted = false;

	ALTER TABLE usermap ALTER COLUMN id_usermap SET DEFAULT nextval(('"usermap_id_usermap_seq"'::text)::regclass);
    ALTER TABLE usermap ALTER COLUMN creation SET DEFAULT now();
    ALTER TABLE usermap ALTER COLUMN status SET DEFAULT 0;

    REVOKE ALL ON TABLE usermap FROM PUBLIC;
    REVOKE ALL ON TABLE usermap FROM postgres;
    GRANT ALL ON TABLE usermap TO postgres;
    GRANT INSERT,SELECT,UPDATE ON TABLE usermap TO wikidncserver;
    GRANT SELECT ON TABLE usermap TO timecop;
    GRANT ALL ON TABLE usermap TO wikidadmin;


	CREATE OR REPLACE RULE usermap_insert_rule AS
	    ON INSERT TO usermap DO INSTEAD  INSERT INTO full_usermap (id_usermap, id_devicemap, userid, bads, creation, status, note, last_activity, deleted)
	  VALUES (new.id_usermap, new.id_devicemap, new.userid, new.bads, new.creation, new.status, new.note, new.last_activity, false);

	CREATE OR REPLACE RULE usermap_update_rule AS
	    ON UPDATE TO usermap DO INSTEAD  UPDATE full_usermap SET id_usermap = new.id_usermap, id_devicemap = new.id_devicemap, userid = new.userid, bads = new.bads, creation = new.creation, status = new.status, note = new.note, last_activity = new.last_activity
	  WHERE full_usermap.id_usermap = old.id_usermap;

	CREATE OR REPLACE RULE usermap_delete_rule AS ON DELETE TO usermap DO INSTEAD UPDATE full_usermap SET deleted = true WHERE (full_usermap.id_usermap = old.id_usermap);


    CREATE OR REPLACE VIEW usr_dev_dom AS
    SELECT usermap.userid, devicemap.deviceid, domain.code, domain.ddname, usermap.id_usermap, devicemap.id_devicemap, domain.id_domain
       FROM usermap, devicemap, domain
      WHERE usermap.id_devicemap = devicemap.id_devicemap AND domain.id_domain = devicemap.domainid;

    ALTER TABLE usr_dev_dom
      OWNER TO postgres;
    GRANT ALL ON TABLE usr_dev_dom TO postgres;
    GRANT ALL ON TABLE usr_dev_dom TO "wikid-sens";

    CREATE OR REPLACE RULE "_RETURN" AS
        ON SELECT TO usr_dev_dom DO INSTEAD  SELECT usermap.userid, devicemap.deviceid, domain.code, domain.ddname, usermap.id_usermap, devicemap.id_devicemap, domain.id_domain
       FROM usermap, devicemap, domain
      WHERE usermap.id_devicemap = devicemap.id_devicemap AND domain.id_domain = devicemap.domainid;

	  

	CREATE OR REPLACE VIEW regdevice_view AS 
	 SELECT DISTINCT devicemap.id_devicemap, devicemap.deviceid, devicemap.domainid, usermap.userid, devicemap.status, usermap.creation, usermap.id_usermap, usermap.note, full_devices.client_type, usermap.last_activity as user_last_activity, full_devices.last_activity as device_last_activity
	   FROM usermap, devicemap LEFT OUTER JOIN full_devices ON (devicemap.deviceid = full_devices.deviceid)
	  WHERE devicemap.id_devicemap = usermap.id_devicemap
	  ORDER BY usermap.userid, devicemap.deviceid, devicemap.domainid, devicemap.id_devicemap, devicemap.status, usermap.creation, usermap.id_usermap;


	CREATE OR REPLACE RULE "_RETURN" AS
        ON SELECT TO regdevice_view DO INSTEAD  SELECT DISTINCT devicemap.id_devicemap, devicemap.deviceid, devicemap.domainid, usermap.userid, devicemap.status, usermap.creation, usermap.id_usermap, usermap.note, full_devices.client_type, usermap.last_activity AS user_last_activity, full_devices.last_activity AS device_last_activity
       FROM usermap, devicemap
       LEFT JOIN full_devices ON devicemap.deviceid = full_devices.deviceid
      WHERE devicemap.id_devicemap = usermap.id_devicemap
      ORDER BY usermap.userid, devicemap.deviceid, devicemap.domainid, devicemap.id_devicemap, devicemap.status, usermap.creation, usermap.id_usermap;


    RETURN TRUE;


EXCEPTION

	WHEN syntax_error_or_access_rule_violation THEN
		RAISE NOTICE 'dbmigrate17:   This migration has already been performed ';
		RETURN FALSE;


END;
$$ LANGUAGE plpgsql;

----

----------------------------------------------------------------
-- dbmigrate18
----------------------------------------------------------------

CREATE OR REPLACE FUNCTION dbmigrate18() RETURNS bool AS $$
BEGIN

	ALTER TABLE full_devicemap ADD COLUMN disable_date timestamp with time zone;
	ALTER TABLE full_devicemap ADD COLUMN disable_cause integer NOT NULL DEFAULT -1;

	
	-- View: devicemap

	DROP VIEW devicemap CASCADE;
		
	CREATE OR REPLACE VIEW devicemap AS 
	 	SELECT full_devicemap.id_devicemap, full_devicemap.deviceid, full_devicemap.domainid, full_devicemap.pin, full_devicemap.offkeypub, full_devicemap.offkeypriv, full_devicemap.status, full_devicemap.bads, full_devicemap.offs, full_devicemap.init_expire, full_devicemap.creation, full_devicemap.disable_date, full_devicemap.disable_cause
	  FROM full_devicemap
	  WHERE full_devicemap.deleted = false;

	ALTER TABLE devicemap ALTER COLUMN id_devicemap SET DEFAULT nextval(('"devicemap_id_devicemap_seq"'::text)::regclass);
    ALTER TABLE devicemap ALTER COLUMN status SET DEFAULT 1;
    ALTER TABLE devicemap ALTER COLUMN creation SET DEFAULT now();

    REVOKE ALL ON TABLE devicemap FROM PUBLIC;
    REVOKE ALL ON TABLE devicemap FROM postgres;
    GRANT ALL ON TABLE devicemap TO postgres;
    GRANT SELECT,UPDATE,DELETE ON TABLE devicemap TO wikidncserver;
    GRANT SELECT,UPDATE,DELETE ON TABLE devicemap TO timecop;
    GRANT ALL ON TABLE devicemap TO wikidadmin;

	
	-- Rule: devicemap_insert_rule ON devicemap
	
	CREATE OR REPLACE RULE devicemap_insert_rule AS
	    ON INSERT TO devicemap DO INSTEAD  INSERT INTO full_devicemap (id_devicemap, deviceid, domainid, pin, offkeypub, offkeypriv, status, bads, offs, init_expire, creation, deleted, disable_date)
	  VALUES (new.id_devicemap, new.deviceid, new.domainid, new.pin, new.offkeypub, new.offkeypriv, new.status, new.bads, new.offs, new.init_expire, new.creation, false, new.disable_date);
	
	-- Rule: devicemap_update_rule ON devicemap
		
	CREATE OR REPLACE RULE devicemap_update_rule AS
	    ON UPDATE TO devicemap DO INSTEAD  UPDATE full_devicemap SET id_devicemap = new.id_devicemap, deviceid = new.deviceid, domainid = new.domainid, pin = new.pin,
		offkeypub = new.offkeypub, offkeypriv = new.offkeypriv, status = new.status, bads = new.bads, offs = new.offs, init_expire = new.init_expire, creation = new.creation, disable_date = new.disable_date, disable_cause = new.disable_cause
	  WHERE full_devicemap.id_devicemap = old.id_devicemap;

	CREATE OR REPLACE RULE devicemap_delete_rule AS ON DELETE TO devicemap DO INSTEAD UPDATE full_devicemap SET deleted = true WHERE (full_devicemap.id_devicemap = old.id_devicemap);


	
	ALTER TABLE full_usermap ADD COLUMN disable_date timestamp with time zone;
	ALTER TABLE full_usermap ADD COLUMN disable_cause integer NOT NULL DEFAULT -1;

	DROP VIEW usermap;
	
	CREATE OR REPLACE VIEW usermap AS 
 		SELECT full_usermap.id_usermap, full_usermap.id_devicemap, full_usermap.userid, full_usermap.bads, full_usermap.creation, full_usermap.status, full_usermap.note, full_usermap.last_activity, full_usermap.disable_date, full_usermap.disable_cause
   	FROM full_usermap
  	WHERE full_usermap.deleted = false;

  	ALTER TABLE usermap ALTER COLUMN id_usermap SET DEFAULT nextval(('"usermap_id_usermap_seq"'::text)::regclass);
    ALTER TABLE usermap ALTER COLUMN creation SET DEFAULT now();
    ALTER TABLE usermap ALTER COLUMN status SET DEFAULT 0;

    REVOKE ALL ON TABLE usermap FROM PUBLIC;
    REVOKE ALL ON TABLE usermap FROM postgres;
    GRANT ALL ON TABLE usermap TO postgres;
    GRANT INSERT,SELECT,UPDATE ON TABLE usermap TO wikidncserver;
    GRANT SELECT ON TABLE usermap TO timecop;
    GRANT ALL ON TABLE usermap TO wikidadmin;

  	
	-- Rule: usermap_insert_rule ON usermap
	
	CREATE OR REPLACE RULE usermap_insert_rule AS
	    ON INSERT TO usermap DO INSTEAD  INSERT INTO full_usermap (id_usermap, id_devicemap, userid, bads, creation, status, note, last_activity, deleted, disable_date)
	  VALUES (new.id_usermap, new.id_devicemap, new.userid, new.bads, new.creation, new.status, new.note, new.last_activity, false, new.disable_date);

	-- Rule: usermap_update_rule ON usermap
	
	CREATE OR REPLACE RULE usermap_update_rule AS
	    ON UPDATE TO usermap DO INSTEAD  UPDATE full_usermap SET id_usermap = new.id_usermap, id_devicemap = new.id_devicemap, userid = new.userid, bads = new.bads, 
	    creation = new.creation, status = new.status, note = new.note, last_activity = new.last_activity, disable_date = new.disable_date, disable_cause = new.disable_cause
	  WHERE full_usermap.id_usermap = old.id_usermap;

	CREATE OR REPLACE RULE usermap_delete_rule AS ON DELETE TO usermap DO INSTEAD UPDATE full_usermap SET deleted = true WHERE (full_usermap.id_usermap = old.id_usermap);



	      CREATE OR REPLACE VIEW usr_dev_dom AS
    SELECT usermap.userid, devicemap.deviceid, domain.code, domain.ddname, usermap.id_usermap, devicemap.id_devicemap, domain.id_domain
       FROM usermap, devicemap, domain
      WHERE usermap.id_devicemap = devicemap.id_devicemap AND domain.id_domain = devicemap.domainid;

    ALTER TABLE usr_dev_dom
      OWNER TO postgres;
    GRANT ALL ON TABLE usr_dev_dom TO postgres;
    GRANT ALL ON TABLE usr_dev_dom TO "wikid-sens";

    CREATE OR REPLACE RULE "_RETURN" AS
        ON SELECT TO usr_dev_dom DO INSTEAD  SELECT usermap.userid, devicemap.deviceid, domain.code, domain.ddname, usermap.id_usermap, devicemap.id_devicemap, domain.id_domain
       FROM usermap, devicemap, domain
      WHERE usermap.id_devicemap = devicemap.id_devicemap AND domain.id_domain = devicemap.domainid;



	CREATE OR REPLACE VIEW regdevice_view AS
	 SELECT DISTINCT devicemap.id_devicemap, devicemap.deviceid, devicemap.domainid, usermap.userid, devicemap.status, usermap.creation, usermap.id_usermap, usermap.note, full_devices.client_type, usermap.last_activity as user_last_activity, full_devices.last_activity as device_last_activity
	   FROM usermap, devicemap LEFT OUTER JOIN full_devices ON (devicemap.deviceid = full_devices.deviceid)
	  WHERE devicemap.id_devicemap = usermap.id_devicemap
	  ORDER BY usermap.userid, devicemap.deviceid, devicemap.domainid, devicemap.id_devicemap, devicemap.status, usermap.creation, usermap.id_usermap;

    REVOKE ALL ON TABLE regdevice_view FROM PUBLIC;
    REVOKE ALL ON TABLE regdevice_view FROM postgres;
    GRANT ALL ON TABLE regdevice_view TO postgres;
    GRANT ALL ON TABLE regdevice_view TO "wikid-sens";


	CREATE OR REPLACE RULE "_RETURN" AS
        ON SELECT TO regdevice_view DO INSTEAD  SELECT DISTINCT devicemap.id_devicemap, devicemap.deviceid, devicemap.domainid, usermap.userid, devicemap.status, usermap.creation, usermap.id_usermap, usermap.note, full_devices.client_type, usermap.last_activity AS user_last_activity, full_devices.last_activity AS device_last_activity
       FROM usermap, devicemap
       LEFT JOIN full_devices ON devicemap.deviceid = full_devices.deviceid
      WHERE devicemap.id_devicemap = usermap.id_devicemap
      ORDER BY usermap.userid, devicemap.deviceid, devicemap.domainid, devicemap.id_devicemap, devicemap.status, usermap.creation, usermap.id_usermap;

  	
    RETURN TRUE;


EXCEPTION

	WHEN syntax_error_or_access_rule_violation THEN
		RAISE NOTICE 'dbmigrate18:   This migration has already been performed ';
		RETURN FALSE;


END;
$$ LANGUAGE plpgsql;



----------------------------------------------------------------
-- dbmigrate19
----------------------------------------------------------------

-- Change the size of the secret column to 128
CREATE OR REPLACE FUNCTION dbmigrate19() RETURNS bool AS $$
BEGIN

  DROP RULE network_client_delete_rule ON network_client;
  DROP RULE network_client_insert_rule ON network_client;
  DROP RULE network_client_update_rule ON network_client;
  DROP VIEW prot_view;
  DROP VIEW radius_nc_view;
  DROP VIEW network_client;


  ALTER TABLE full_network_client
  ALTER COLUMN secret TYPE character(128);


  CREATE OR REPLACE VIEW network_client AS
    SELECT full_network_client.id_nc, full_network_client.ip,
      full_network_client.name, full_network_client.secret,
      full_network_client.enforced, full_network_client.domain,
      full_network_client.creation
    FROM full_network_client
    WHERE full_network_client.deleted = false AND full_network_client.id_nc > 0;

  ALTER TABLE network_client
  OWNER TO postgres;
  GRANT ALL ON TABLE network_client TO postgres;
  GRANT ALL ON TABLE network_client TO "wikid-sens";
  GRANT ALL ON TABLE network_client TO timecop;

  ALTER TABLE network_client ALTER COLUMN id_nc SET DEFAULT nextval(('"network_client_id_nc_seq"'::text)::regclass);
  ALTER TABLE network_client ALTER COLUMN creation SET DEFAULT now();


  CREATE OR REPLACE VIEW prot_view AS
    SELECT DISTINCT network_client.id_nc, host.type
    FROM network_client, host, host_nc_map
    WHERE host.id_host = host_nc_map.host AND network_client.id_nc = host_nc_map.nc
    ORDER BY network_client.id_nc, host.type;

  ALTER TABLE prot_view
  OWNER TO postgres;
  GRANT ALL ON TABLE prot_view TO postgres;
  GRANT ALL ON TABLE prot_view TO "wikid-sens";


  CREATE OR REPLACE VIEW radius_nc_view AS
    SELECT host.id_host, domain.code AS domain, host_nc_map.host, host_nc_map.nc,
      network_client.id_nc, network_client.name, network_client.ip,
      network_client.secret, network_client.enforced,
                         network_client.domain AS nc_domain
    FROM host_nc_map, network_client, host, domain
    WHERE network_client.domain = domain.id_domain AND host.id_host = host_nc_map.host AND network_client.id_nc = host_nc_map.nc AND host.type = 1;

  ALTER TABLE radius_nc_view
  OWNER TO postgres;
  GRANT ALL ON TABLE radius_nc_view TO postgres;
  GRANT ALL ON TABLE radius_nc_view TO "wikid-sens";


  CREATE OR REPLACE RULE network_client_delete_rule AS
  ON DELETE TO network_client DO INSTEAD  UPDATE full_network_client SET deleted = true
  WHERE full_network_client.id_nc = old.id_nc;


  CREATE OR REPLACE RULE network_client_insert_rule AS
  ON INSERT TO network_client DO INSTEAD  INSERT INTO full_network_client (id_nc, ip, name, secret, enforced, domain, creation, deleted)
    VALUES (new.id_nc, new.ip, new.name, new.secret, new.enforced, new.domain, new.creation, false);


  CREATE OR REPLACE RULE network_client_update_rule AS
  ON UPDATE TO network_client DO INSTEAD  UPDATE full_network_client SET id_nc = new.id_nc, ip = new.ip, name = new.name, secret = new.secret, enforced = new.enforced, domain = new.domain, creation = new.creation
  WHERE full_network_client.id_nc = old.id_nc;

  RETURN TRUE;


  EXCEPTION

  WHEN syntax_error_or_access_rule_violation THEN
    RAISE NOTICE 'dbmigrate19:   This migration has already been performed ';
    RETURN FALSE;

END;
$$ LANGUAGE plpgsql;

----

select dbmigrate0();
select dbmigrate1();
select dbmigrate2();
select dbmigrate3();
select dbmigrate4();
select dbmigrate5();
select dbmigrate6();
select dbmigrate7();
select dbmigrate8();
select dbmigrate9();
select dbmigrate10();
select dbmigrate11();
select dbmigrate12();
select dbmigrate13();
select dbmigrate14();
select dbmigrate15();
select dbmigrate16();
select dbmigrate17();
select dbmigrate18();
select dbmigrate19();

-- These rules should be valid in the functions but the pgsql parser rejects them so they are executed unconditionally here

CREATE OR REPLACE RULE devices_insert_rule AS
	ON INSERT TO devices DO INSTEAD  INSERT INTO full_devices (id_devices, deviceid, ckey, id_cryptotype, lockcode, init_expire, creation, client_type, last_activity, deleted)
  VALUES (new.id_devices, new.deviceid, new.ckey, new.id_cryptotype, new.lockcode, new.init_expire, new.creation, new.client_type, new.last_activity, false);

CREATE OR REPLACE RULE domain_insert_rule AS 
			ON INSERT TO "domain" DO INSTEAD INSERT INTO full_domain (id_domain, code, name, ddname, registered_url, registered_url_hash, minpin, "valid", maxbads, maxoffs, lockrequired, clients_allowed, tacacs, maxattempts, publickey, privatekey, creation, reset_domain, nt_host, admin_user, admin_passwd, nt_domain_name, use_saml, saml_idp_url, saml_assertion_timelimit, deleted) 
		VALUES (new.id_domain, new.code, new.name, new.ddname, new.registered_url, new.registered_url_hash, new.minpin, new."valid", new.maxbads, new.maxoffs, new.lockrequired, new.clients_allowed, new.tacacs, new.maxattempts, new.publickey, new.privatekey, new.creation, new.reset_domain, new.nt_host, new.admin_user, new.admin_passwd, new.nt_domain_name, 0, new.saml_idp_url, new.saml_assertion_timelimit, false);

-- Finally, update the db_version to represent all updates applied

update db_version set version=19;
