--
-- PostgreSQL database dump
--

SET client_encoding = 'SQL_ASCII';
SET check_function_bodies = false;

SET SESSION AUTHORIZATION 'postgres';

--
-- TOC entry 2 (OID 0)
-- Name: wikid; Type: DATABASE; Schema: -; Owner: postgres
--

CREATE DATABASE wikid WITH TEMPLATE = template0 ENCODING = 'SQL_ASCII';


\connect wikid postgres

SET client_encoding = 'SQL_ASCII';
SET check_function_bodies = false;

SET search_path = public, pg_catalog;

--
-- TOC entry 167 (OID 17143)
-- Name: plpgsql_call_handler(); Type: FUNC PROCEDURAL LANGUAGE; Schema: public; Owner: postgres
--

CREATE FUNCTION plpgsql_call_handler() RETURNS language_handler
    AS '$libdir/plpgsql', 'plpgsql_call_handler'
    LANGUAGE c;


SET SESSION AUTHORIZATION DEFAULT;

--
-- TOC entry 166 (OID 17144)
-- Name: plpgsql; Type: PROCEDURAL LANGUAGE; Schema: public; Owner:
--

CREATE TRUSTED PROCEDURAL LANGUAGE plpgsql HANDLER plpgsql_call_handler;


SET SESSION AUTHORIZATION 'postgres';

--
-- TOC entry 4 (OID 2200)
-- Name: public; Type: ACL; Schema: -; Owner: postgres
--

REVOKE ALL ON SCHEMA public FROM PUBLIC;
GRANT ALL ON SCHEMA public TO PUBLIC;


--
-- TOC entry 5 (OID 17145)
-- Name: domain_id_domain_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE domain_id_domain_seq
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


--
-- TOC entry 6 (OID 17145)
-- Name: domain_id_domain_seq; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE domain_id_domain_seq FROM PUBLIC;
GRANT ALL ON TABLE domain_id_domain_seq TO GROUP "wikid-sens";


--
-- TOC entry 44 (OID 17147)
-- Name: full_domain; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE full_domain (
    id_domain bigint DEFAULT nextval('"domain_id_domain_seq"'::text) NOT NULL,
    code character(12) NOT NULL,
    name character(32) NOT NULL,
    ddname character varying(20) NOT NULL,
    minpin integer NOT NULL,
    "valid" integer NOT NULL,
    maxbads integer NOT NULL,
    maxoffs integer NOT NULL,
    lockrequired boolean DEFAULT false,
    clients_allowed bigint NOT NULL DEFAULT 0,
    use_saml integer NOT NULL DEFAULT 0, 
    saml_idp_url character varying(256), 
    saml_assertion_timelimit integer,
    tacacs integer NOT NULL,
    maxattempts integer DEFAULT 0 NOT NULL,
    publickey bytea NOT NULL,
    privatekey bytea NOT NULL,
    creation timestamp with time zone DEFAULT now() NOT NULL,
    reset_domain character(1),
    nt_host character varying(256),
    admin_user character varying(256),
    admin_passwd character varying(256),
    nt_domain_name character varying(256),
    deleted boolean DEFAULT false NOT NULL,
		registered_url character varying(256),
  	registered_url_hash TEXT 

);


--
-- TOC entry 45 (OID 17147)
-- Name: full_domain; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE full_domain FROM PUBLIC;
GRANT SELECT ON TABLE full_domain TO wikidadmin;


--
-- TOC entry 46 (OID 17158)
-- Name: domain; Type: VIEW; Schema: public; Owner: postgres
--

	CREATE VIEW "domain" AS
			SELECT full_domain.id_domain, full_domain.code, full_domain.name, full_domain.ddname, full_domain.registered_url, full_domain.registered_url_hash, full_domain.minpin, full_domain."valid", full_domain.maxbads, full_domain.maxoffs, full_domain.maxattempts, full_domain.publickey, full_domain.privatekey, full_domain.creation, full_domain.reset_domain, full_domain.nt_host, full_domain.admin_user, full_domain.admin_passwd, full_domain.nt_domain_name, full_domain.tacacs, full_domain.lockrequired, full_domain.clients_allowed, full_domain.use_saml, full_domain.saml_idp_url, full_domain.saml_assertion_timelimit FROM full_domain WHERE ((full_domain.deleted = false) AND (full_domain.id_domain > 0));
ALTER TABLE "domain" ALTER COLUMN id_domain SET DEFAULT nextval('"domain_id_domain_seq"'::text);
ALTER TABLE "domain" ALTER COLUMN maxattempts SET DEFAULT 0;
ALTER TABLE "domain" ALTER COLUMN creation SET DEFAULT now();


--
-- TOC entry 47 (OID 17158)
-- Name: domain; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE "domain" FROM PUBLIC;
GRANT SELECT ON TABLE "domain" TO wikidncserver;
GRANT ALL ON TABLE "domain" TO wikidadmin;


--
-- TOC entry 168 (OID 17162)
-- Name: domain_delete_func(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION domain_delete_func() RETURNS "trigger"
    AS '
	DECLARE
		tmp RECORD;
	BEGIN
		IF NEW.deleted = TRUE AND OLD.deleted = FALSE THEN

			SELECT INTO tmp * FROM devicemap WHERE domainid = OLD.id_domain;
			IF FOUND THEN
				RAISE EXCEPTION ''can not set "deleted" to TRUE - data in table "devicemap" references the primary key with the value "%"'', OLD.id_domain;
			END IF;


			SELECT INTO tmp * FROM network_client WHERE domain = OLD.id_domain;
			IF FOUND THEN
				RAISE EXCEPTION ''can not set "deleted" to TRUE - data in table "network_client" references the primary key with the value "%"'', OLD.id_domain;
			END IF;

		END IF;

		RETURN NEW;
	END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 7 (OID 17163)
-- Name: devicemap_id_devicemap_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE devicemap_id_devicemap_seq
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


--
-- TOC entry 8 (OID 17163)
-- Name: devicemap_id_devicemap_seq; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE devicemap_id_devicemap_seq FROM PUBLIC;
GRANT ALL ON TABLE devicemap_id_devicemap_seq TO GROUP "wikid-sens";


--
-- TOC entry 48 (OID 17165)
-- Name: full_devicemap; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE full_devicemap (
    id_devicemap bigint DEFAULT nextval('"devicemap_id_devicemap_seq"'::text) NOT NULL,
    deviceid bigint NOT NULL,
    domainid bigint NOT NULL,
    pin bytea NOT NULL,
    offkeypub bytea NOT NULL,
    offkeypriv bytea NOT NULL,
    status integer DEFAULT 1 NOT NULL,
    bads integer NOT NULL,
    offs integer NOT NULL,
    init_expire timestamp with time zone NOT NULL,
    creation timestamp with time zone DEFAULT now() NOT NULL,
    deleted boolean DEFAULT false NOT NULL,
    disable_date timestamp with time zone,
    disable_cause integer NOT NULL DEFAULT -1
);


--
-- TOC entry 49 (OID 17165)
-- Name: full_devicemap; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE full_devicemap FROM PUBLIC;
GRANT ALL ON TABLE full_devicemap TO wikidadmin;
GRANT ALL ON TABLE full_devicemap TO wikidncserver;


--
-- TOC entry 50 (OID 17176)
-- Name: devicemap; Type: VIEW; Schema: public; Owner: postgres
--

CREATE OR REPLACE VIEW devicemap AS 
	 	SELECT full_devicemap.id_devicemap, full_devicemap.deviceid, full_devicemap.domainid, full_devicemap.pin, full_devicemap.offkeypub, full_devicemap.offkeypriv, full_devicemap.status, full_devicemap.bads, full_devicemap.offs, full_devicemap.init_expire, full_devicemap.creation, full_devicemap.disable_date, full_devicemap.disable_cause
	  FROM full_devicemap
	  WHERE full_devicemap.deleted = false;
ALTER TABLE devicemap ALTER COLUMN id_devicemap SET DEFAULT nextval('"devicemap_id_devicemap_seq"'::text);
ALTER TABLE devicemap ALTER COLUMN status SET DEFAULT 1;
ALTER TABLE devicemap ALTER COLUMN creation SET DEFAULT now();


--
-- TOC entry 51 (OID 17176)
-- Name: devicemap; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE devicemap FROM PUBLIC;
GRANT SELECT,UPDATE,DELETE ON TABLE devicemap TO wikidncserver;
GRANT SELECT,UPDATE,DELETE ON TABLE devicemap TO timecop;
GRANT ALL ON TABLE devicemap TO wikidadmin;


--
-- TOC entry 169 (OID 17180)
-- Name: devicemap_delete_func(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION devicemap_delete_func() RETURNS "trigger"
    AS '
	DECLARE
		tmp RECORD;
	BEGIN
		IF NEW.deleted = TRUE AND OLD.deleted = FALSE THEN
			-- SELECT INTO tmp * FROM ReplaceMe WHERE id_devicemap = OLD.id_devicemap;
			-- IF FOUND THEN
			-- 	RAISE EXCEPTION ''can not set "deleted" to TRUE - data in table "ReplaceMe" references the primary key with the value "%"'', OLD.id_devicemap;
			-- END IF;
		END IF;

		RETURN NEW;
	END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 9 (OID 17181)
-- Name: curr_codes_id_curr_codes_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE curr_codes_id_curr_codes_seq
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


--
-- TOC entry 10 (OID 17181)
-- Name: curr_codes_id_curr_codes_seq; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE curr_codes_id_curr_codes_seq FROM PUBLIC;
GRANT ALL ON TABLE curr_codes_id_curr_codes_seq TO GROUP "wikid-sens";


--
-- TOC entry 52 (OID 17183)
-- Name: curr_codes; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE curr_codes (
    id_curr_codes bigint DEFAULT nextval('"curr_codes_id_curr_codes_seq"'::text) NOT NULL,
    id_devicemap bigint NOT NULL,
    code bigint NOT NULL,
    creation timestamp with time zone DEFAULT now() NOT NULL,
    expire timestamp with time zone
);


--
-- TOC entry 53 (OID 17183)
-- Name: curr_codes; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE curr_codes FROM PUBLIC;
GRANT SELECT,UPDATE,DELETE ON TABLE curr_codes TO wikidncserver;
GRANT SELECT,UPDATE,DELETE ON TABLE curr_codes TO timecop;
GRANT ALL ON TABLE curr_codes TO wikidadmin;


--
-- TOC entry 11 (OID 17187)
-- Name: devices_id_devices_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE devices_id_devices_seq
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


--
-- TOC entry 12 (OID 17187)
-- Name: devices_id_devices_seq; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE devices_id_devices_seq FROM PUBLIC;
GRANT ALL ON TABLE devices_id_devices_seq TO GROUP "wikid-sens";


--
-- TOC entry 13 (OID 17189)
-- Name: tempregcodes_id_tempregcode_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE tempregcodes_id_tempregcode_seq
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


--
-- TOC entry 14 (OID 17189)
-- Name: tempregcodes_id_tempregcode_seq; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE tempregcodes_id_tempregcode_seq FROM PUBLIC;
GRANT ALL ON TABLE tempregcodes_id_tempregcode_seq TO GROUP "wikid-sens";


--
-- TOC entry 15 (OID 17191)
-- Name: usermap_id_usermap_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE usermap_id_usermap_seq
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


--
-- TOC entry 16 (OID 17191)
-- Name: usermap_id_usermap_seq; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE usermap_id_usermap_seq FROM PUBLIC;
GRANT ALL ON TABLE usermap_id_usermap_seq TO GROUP "wikid-sens";


--
-- TOC entry 54 (OID 17193)
-- Name: full_usermap; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE full_usermap (
    id_usermap bigint DEFAULT nextval('"usermap_id_usermap_seq"'::text) NOT NULL,
    id_devicemap bigint NOT NULL,
    userid character(255) NOT NULL,
    bads integer NOT NULL,
    creation timestamp with time zone DEFAULT now() NOT NULL,
    status integer DEFAULT 0 NOT NULL,
    deleted boolean DEFAULT false NOT NULL,
    note character varying(50),
    last_activity date,
    disable_date timestamp with time zone,
    disable_cause integer NOT NULL DEFAULT -1
);


--
-- TOC entry 55 (OID 17193)
-- Name: full_usermap; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE full_usermap FROM PUBLIC;
GRANT SELECT ON TABLE full_usermap TO wikidadmin;
GRANT ALL ON TABLE full_usermap TO GROUP "wikid-sens";


--
-- TOC entry 56 (OID 17201)
-- Name: usermap; Type: VIEW; Schema: public; Owner: postgres
--

CREATE OR REPLACE VIEW usermap AS 
	SELECT full_usermap.id_usermap, full_usermap.id_devicemap, full_usermap.userid, full_usermap.bads, full_usermap.creation, full_usermap.status, full_usermap.note, full_usermap.last_activity, full_usermap.disable_date, full_usermap.disable_cause
 	FROM full_usermap
	WHERE full_usermap.deleted = false;
ALTER TABLE usermap ALTER COLUMN id_usermap SET DEFAULT nextval('"usermap_id_usermap_seq"'::text);
ALTER TABLE usermap ALTER COLUMN creation SET DEFAULT now();
ALTER TABLE usermap ALTER COLUMN status SET DEFAULT 0;


--
-- TOC entry 57 (OID 17201)
-- Name: usermap; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE usermap FROM PUBLIC;
GRANT INSERT,SELECT,UPDATE ON TABLE usermap TO wikidncserver;
GRANT SELECT ON TABLE usermap TO timecop;
GRANT ALL ON TABLE usermap TO wikidadmin;


--
-- TOC entry 170 (OID 17205)
-- Name: usermap_delete_func(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION usermap_delete_func() RETURNS "trigger"
    AS '
	DECLARE
		tmp RECORD;
	BEGIN
		IF NEW.deleted = TRUE AND OLD.deleted = FALSE THEN
			-- SELECT INTO tmp * FROM ReplaceMe WHERE id_usermap = OLD.id_usermap;
			-- IF FOUND THEN
			-- 	RAISE EXCEPTION ''can not set "deleted" to TRUE - data in table "ReplaceMe" references the primary key with the value "%"'', OLD.id_usermap;
			-- END IF;
		END IF;

		RETURN NEW;
	END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 17 (OID 17206)
-- Name: network_client_id_nc_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE network_client_id_nc_seq
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


--
-- TOC entry 18 (OID 17206)
-- Name: network_client_id_nc_seq; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE network_client_id_nc_seq FROM PUBLIC;
GRANT ALL ON TABLE network_client_id_nc_seq TO GROUP "wikid-sens";


--
-- TOC entry 58 (OID 17208)
-- Name: full_network_client; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE full_network_client (
    id_nc bigint DEFAULT nextval('"network_client_id_nc_seq"'::text) NOT NULL,
    ip inet NOT NULL,
    name character(50) NOT NULL,
    secret character(25),
    enforced integer NOT NULL,
    "domain" bigint NOT NULL,
    creation timestamp with time zone DEFAULT now() NOT NULL,
    deleted boolean DEFAULT false NOT NULL
);


--
-- TOC entry 59 (OID 17208)
-- Name: full_network_client; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE full_network_client FROM PUBLIC;
GRANT SELECT ON TABLE full_network_client TO wikidadmin;


--
-- TOC entry 60 (OID 17218)
-- Name: network_client; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW network_client AS
    SELECT full_network_client.id_nc, full_network_client.ip, full_network_client.name, full_network_client.secret, full_network_client.enforced, full_network_client."domain", full_network_client.creation FROM full_network_client WHERE ((full_network_client.deleted = false) AND (full_network_client.id_nc > 0));
ALTER TABLE network_client ALTER COLUMN id_nc SET DEFAULT nextval('"network_client_id_nc_seq"'::text);
ALTER TABLE network_client ALTER COLUMN creation SET DEFAULT now();


--
-- TOC entry 61 (OID 17218)
-- Name: network_client; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE network_client FROM PUBLIC;
GRANT ALL ON TABLE network_client TO GROUP "wikid-sens";


--
-- TOC entry 171 (OID 17221)
-- Name: network_client_delete_func(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION network_client_delete_func() RETURNS "trigger"
    AS '
	DECLARE
		tmp RECORD;
	BEGIN
		IF NEW.deleted = TRUE AND OLD.deleted = FALSE THEN
			-- SELECT INTO tmp * FROM ReplaceMe WHERE id_nc = OLD.id_nc;
			-- IF FOUND THEN
			-- 	RAISE EXCEPTION ''can not set "deleted" to TRUE - data in table "ReplaceMe" references the primary key with the value "%"'', OLD.id_nc;
			-- END IF;
		END IF;

		RETURN NEW;
	END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 19 (OID 17222)
-- Name: host_id_host_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE host_id_host_seq
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


--
-- TOC entry 20 (OID 17222)
-- Name: host_id_host_seq; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE host_id_host_seq FROM PUBLIC;
GRANT ALL ON TABLE host_id_host_seq TO GROUP "wikid-sens";


--
-- TOC entry 62 (OID 17224)
-- Name: host; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE host (
    id_host bigint DEFAULT nextval('"host_id_host_seq"'::text) NOT NULL,
    ip inet NOT NULL,
    name character(50) NOT NULL,
    port integer NOT NULL,
    enabled integer NOT NULL,
    config character varying(255) NOT NULL,
    "type" integer NOT NULL,
    subtype integer NOT NULL,
    debug_level integer NOT NULL,
    multihome integer NOT NULL,
    restrict_nc integer NOT NULL,
    proxy integer,
    creation timestamp with time zone DEFAULT now() NOT NULL
);


--
-- TOC entry 63 (OID 17224)
-- Name: host; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE host FROM PUBLIC;
GRANT ALL ON TABLE host TO GROUP "wikid-sens";


--
-- TOC entry 21 (OID 17231)
-- Name: host_nc_map_id_hostncmap_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE host_nc_map_id_hostncmap_seq
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


--
-- TOC entry 22 (OID 17231)
-- Name: host_nc_map_id_hostncmap_seq; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE host_nc_map_id_hostncmap_seq FROM PUBLIC;
GRANT ALL ON TABLE host_nc_map_id_hostncmap_seq TO GROUP "wikid-sens";


--
-- TOC entry 64 (OID 17233)
-- Name: host_nc_map; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE host_nc_map (
    id_hostncmap bigint DEFAULT nextval('"host_nc_map_id_hostncmap_seq"'::text) NOT NULL,
    host bigint NOT NULL,
    nc bigint NOT NULL,
    creation timestamp with time zone DEFAULT now() NOT NULL
);


--
-- TOC entry 65 (OID 17233)
-- Name: host_nc_map; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE host_nc_map FROM PUBLIC;
GRANT ALL ON TABLE host_nc_map TO GROUP "wikid-sens";


--
-- TOC entry 23 (OID 17237)
-- Name: host_subtype_id_hostsubtype_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE host_subtype_id_hostsubtype_seq
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


--
-- TOC entry 24 (OID 17237)
-- Name: host_subtype_id_hostsubtype_seq; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE host_subtype_id_hostsubtype_seq FROM PUBLIC;
GRANT ALL ON TABLE host_subtype_id_hostsubtype_seq TO GROUP "wikid-sens";


--
-- TOC entry 66 (OID 17239)
-- Name: host_subtype; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE host_subtype (
    id_hostsubtype bigint DEFAULT nextval('"host_subtype_id_hostsubtype_seq"'::text) NOT NULL,
    subtype integer NOT NULL,
    name character(50) NOT NULL,
    creation timestamp with time zone DEFAULT now() NOT NULL
);


--
-- TOC entry 67 (OID 17239)
-- Name: host_subtype; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE host_subtype FROM PUBLIC;
GRANT ALL ON TABLE host_subtype TO GROUP "wikid-sens";


--
-- TOC entry 25 (OID 17243)
-- Name: host_type_id_hosttype_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE host_type_id_hosttype_seq
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


--
-- TOC entry 26 (OID 17243)
-- Name: host_type_id_hosttype_seq; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE host_type_id_hosttype_seq FROM PUBLIC;
GRANT ALL ON TABLE host_type_id_hosttype_seq TO GROUP "wikid-sens";


--
-- TOC entry 68 (OID 17245)
-- Name: host_type; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE host_type (
    id_hosttype bigint DEFAULT nextval('"host_type_id_hosttype_seq"'::text) NOT NULL,
    "type" integer NOT NULL,
    name character(50) NOT NULL,
    creation timestamp with time zone DEFAULT now() NOT NULL
);


--
-- TOC entry 69 (OID 17245)
-- Name: host_type; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE host_type FROM PUBLIC;
GRANT ALL ON TABLE host_type TO GROUP "wikid-sens";


--
-- TOC entry 27 (OID 17249)
-- Name: usr_id_user_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE usr_id_user_seq
    START WITH 1
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


--
-- TOC entry 70 (OID 17251)
-- Name: usr; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE usr (
    id_user bigint DEFAULT nextval('"usr_id_user_seq"'::text) NOT NULL,
    userid character(16) NOT NULL,
    firstname character(30) NOT NULL,
    lastname character(30) NOT NULL,
    creation timestamp with time zone DEFAULT now() NOT NULL
);


--
-- TOC entry 71 (OID 17251)
-- Name: usr; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE usr FROM PUBLIC;
GRANT ALL ON TABLE usr TO GROUP "wikid-sens";


--
-- TOC entry 72 (OID 17255)
-- Name: scratch; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE scratch (
    t timestamp with time zone
);


--
-- TOC entry 73 (OID 17259)
-- Name: prot_enabled; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW prot_enabled AS
    SELECT DISTINCT host_type.name, host_type."type" FROM host_type, host WHERE (host_type."type" = host."type") ORDER BY host_type.name, host_type."type";


--
-- TOC entry 74 (OID 17259)
-- Name: prot_enabled; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE prot_enabled FROM PUBLIC;
GRANT ALL ON TABLE prot_enabled TO GROUP "wikid-sens";


--
-- TOC entry 75 (OID 17262)
-- Name: prot_view; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW prot_view AS
    SELECT DISTINCT network_client.id_nc, host."type" FROM network_client, host, host_nc_map WHERE ((host.id_host = host_nc_map.host) AND (network_client.id_nc = host_nc_map.nc)) ORDER BY network_client.id_nc, host."type";


--
-- TOC entry 76 (OID 17262)
-- Name: prot_view; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE prot_view FROM PUBLIC;
GRANT ALL ON TABLE prot_view TO GROUP "wikid-sens";


--
-- TOC entry 28 (OID 17263)
-- Name: profile_id_profile_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE profile_id_profile_seq
    START WITH 1
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


--
-- TOC entry 29 (OID 17263)
-- Name: profile_id_profile_seq; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE profile_id_profile_seq FROM PUBLIC;
GRANT ALL ON TABLE profile_id_profile_seq TO wikidadmin;


--
-- TOC entry 77 (OID 17265)
-- Name: profile; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE profile (
    id_profile bigint DEFAULT nextval('"profile_id_profile_seq"'::text) NOT NULL,
    "first" character varying(20) NOT NULL,
    middle character varying(20),
    "last" character varying(20) NOT NULL,
    address1 character varying(50) NOT NULL,
    address2 character varying(50),
    city character varying(20) NOT NULL,
    state character(2) NOT NULL,
    zip character(10) NOT NULL,
    country character varying(20) NOT NULL,
    username character(255) NOT NULL,
    company character varying(50),
    phone character varying(12)
);


--
-- TOC entry 78 (OID 17265)
-- Name: profile; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE profile FROM PUBLIC;
GRANT ALL ON TABLE profile TO wikidadmin;


--
-- TOC entry 79 (OID 17268)
-- Name: full_devices; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE full_devices (
    id_devices bigint DEFAULT nextval('"devices_id_devices_seq"'::text) NOT NULL,
    deviceid bigint NOT NULL,
    ckey bytea NOT NULL,
    init_expire timestamp with time zone NOT NULL,
    creation timestamp with time zone DEFAULT now() NOT NULL,
    deleted boolean DEFAULT false NOT NULL,
    id_cryptotype integer,
    lockcode character(50),
    client_type integer NOT NULL DEFAULT 0,
    last_activity date
);


--
-- TOC entry 80 (OID 17268)
-- Name: full_devices; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE full_devices FROM PUBLIC;
GRANT SELECT ON TABLE full_devices TO wikidadmin;


--
-- TOC entry 172 (OID 17281)
-- Name: devices_delete_func(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION devices_delete_func() RETURNS "trigger"
    AS '
	DECLARE
		tmp RECORD;
	BEGIN
		IF NEW.deleted = TRUE AND OLD.deleted = FALSE THEN
			-- SELECT INTO tmp * FROM ReplaceMe WHERE id_devices = OLD.id_devices;
			-- IF FOUND THEN
			-- 	RAISE EXCEPTION ''can not set "deleted" to TRUE - data in table "ReplaceMe" references the primary key with the value "%"'', OLD.id_devices;
			-- END IF;
		END IF;

		RETURN NEW;
	END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 81 (OID 17284)
-- Name: radius_nc_view; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW radius_nc_view AS
   SELECT host.id_host, "domain".code AS "domain", host_nc_map.host, host_nc_map.nc, network_client.id_nc, network_client.name, network_client.ip, network_client.secret, network_client.enforced, network_client."domain" AS nc_domain FROM host_nc_map, network_client, host, "domain" WHERE ((((network_client."domain" = "domain".id_domain) AND (host.id_host = host_nc_map.host)) AND (network_client.id_nc = host_nc_map.nc)) AND (host."type" = 1));


--
-- TOC entry 82 (OID 17284)
-- Name: radius_nc_view; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE radius_nc_view FROM PUBLIC;
GRANT ALL ON TABLE radius_nc_view TO GROUP "wikid-sens";


--
-- TOC entry 83 (OID 17285)
-- Name: help_links; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE help_links (
    link bigint NOT NULL,
    help_text character varying(255),
    more_info character varying(255)
);


--
-- TOC entry 84 (OID 17285)
-- Name: help_links; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE help_links FROM PUBLIC;
GRANT SELECT ON TABLE help_links TO GROUP "wikid-sens";


--
-- TOC entry 85 (OID 17287)
-- Name: parms1to1; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE parms1to1 (
    "key" character varying(32) NOT NULL,
    value character varying(255) NOT NULL,
    description character varying(30) NOT NULL,
    "class" character(20),
    hide boolean DEFAULT false
);


--
-- TOC entry 88 (OID 17287)
-- Name: parms1to1; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE parms1to1 FROM PUBLIC;
GRANT SELECT ON TABLE parms1to1 TO timecop;
GRANT ALL ON TABLE parms1to1 TO GROUP "wikid-sens";


--
-- TOC entry 89 (OID 17290)
-- Name: nc_return_attrib; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE nc_return_attrib (
    id_attrib bigint DEFAULT nextval('"id_attrib_seq"'::text) NOT NULL,
    id_nc bigint NOT NULL,
    akey character(100) NOT NULL,
    avalue character varying(255) NOT NULL
);


--
-- TOC entry 90 (OID 17290)
-- Name: nc_return_attrib; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE nc_return_attrib FROM PUBLIC;
GRANT ALL ON TABLE nc_return_attrib TO GROUP "wikid-sens";


--
-- TOC entry 30 (OID 17293)
-- Name: id_attrib_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE id_attrib_seq
    START WITH 1
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


--
-- TOC entry 31 (OID 17293)
-- Name: id_attrib_seq; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE id_attrib_seq FROM PUBLIC;
GRANT ALL ON TABLE id_attrib_seq TO GROUP "wikid-sens";


--
-- TOC entry 32 (OID 17295)
-- Name: activity_log_id_activity_lo_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE activity_log_id_activity_lo_seq
    START WITH 1
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


--
-- TOC entry 33 (OID 17295)
-- Name: activity_log_id_activity_lo_seq; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE activity_log_id_activity_lo_seq FROM PUBLIC;
GRANT SELECT ON TABLE activity_log_id_activity_lo_seq TO wikidadmin;
GRANT UPDATE ON TABLE activity_log_id_activity_lo_seq TO GROUP "wikid-sens";


--
-- TOC entry 91 (OID 17299)
-- Name: usr_dev_dom; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW usr_dev_dom AS
	 SELECT usermap.userid, devicemap.deviceid, "domain".code, "domain".ddname, usermap.id_usermap, devicemap.id_devicemap, "domain".id_domain FROM usermap, devicemap, "domain" WHERE ((usermap.id_devicemap = devicemap.id_devicemap) AND ("domain".id_domain = devicemap.domainid));


--
-- TOC entry 92 (OID 17299)
-- Name: usr_dev_dom; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE usr_dev_dom FROM PUBLIC;
GRANT ALL ON TABLE usr_dev_dom TO GROUP "wikid-sens";


--
-- TOC entry 34 (OID 17300)
-- Name: cert_id_cert_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE cert_id_cert_seq
    START WITH 1
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


--
-- TOC entry 93 (OID 17302)
-- Name: cert; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE cert (
    id_cert bigint DEFAULT nextval('"cert_id_cert_seq"'::text) NOT NULL,
    serialnum bigint NOT NULL,
    id_nc bigint NOT NULL,
    csr text,
    certificate text,
    expires timestamp with time zone,
    subjectdn character varying(512)
);


--
-- Name: tomcat_users; Type: TABLE; Schema: public; Owner: tomcat; Tablespace: 
--

CREATE TABLE tomcat_users (
    username character(50) NOT NULL,
    "password" character(200) NOT NULL
);


ALTER TABLE public.tomcat_users OWNER TO tomcat;

--
-- Name: TABLE tomcat_users; Type: COMMENT; Schema: public; Owner: tomcat
--

COMMENT ON TABLE tomcat_users IS 'This table is for the Tomcat JDBC Realm that manages valid logins to the WiKIDAdmin system.';


--
-- TOC entry 104 (OID 17327)
-- Name: tomcat_users; Type: ACL; Schema: public; Owner: tomcat
--

REVOKE ALL ON TABLE tomcat_users FROM PUBLIC;
GRANT ALL ON TABLE tomcat_users TO postgres;
GRANT ALL ON TABLE tomcat_users TO GROUP "wikid-sens";


--
-- Name: tomcat_roles; Type: TABLE; Schema: public; Owner: tomcat; Tablespace: 
--

CREATE TABLE tomcat_roles (
    username character(50) NOT NULL,
    "role" character(50) NOT NULL
);


ALTER TABLE public.tomcat_roles OWNER TO tomcat;

--
-- Name: TABLE tomcat_roles; Type: COMMENT; Schema: public; Owner: tomcat
--

COMMENT ON TABLE tomcat_roles IS 'contains one row for every valid role that is assigned to a particular user';


--
-- TOC entry 107 (OID 17329)
-- Name: tomcat_roles; Type: ACL; Schema: public; Owner: tomcat
--

REVOKE ALL ON TABLE tomcat_roles FROM PUBLIC;
GRANT ALL ON TABLE tomcat_roles TO GROUP "wikid-sens";


SET SESSION AUTHORIZATION 'postgres';

--
-- TOC entry 108 (OID 17331)
-- Name: tempregcodes; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE tempregcodes
(
  id_tempregcodes bigint NOT NULL DEFAULT nextval(('"tempregcodes_id_tempregcode_seq"'::text)::regclass),
  regcode character varying(20) NOT NULL,
  regcode256 character varying(40),
  id_devicemap bigint NOT NULL,
  expiration timestamp with time zone NOT NULL,
  creation timestamp with time zone NOT NULL DEFAULT now(),
  embedded_id character varying(50)
);

--
-- TOC entry 109 (OID 17331)
-- Name: tempregcodes; Type: ACL; Schema: public; Owner: postgres
--

ALTER TABLE tempregcodes OWNER TO postgres;
GRANT ALL ON TABLE tempregcodes TO postgres;
GRANT SELECT, DELETE ON TABLE tempregcodes TO wikidncserver;
GRANT SELECT, UPDATE, DELETE ON TABLE tempregcodes TO timecop;
GRANT ALL ON TABLE tempregcodes TO wikidadmin;

--
-- TOC entry 39 (OID 17335)
-- Name: access_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE access_id_seq
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


--
-- TOC entry 40 (OID 17335)
-- Name: access_id_seq; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE access_id_seq FROM PUBLIC;
GRANT ALL ON TABLE access_id_seq TO GROUP "wikid-sens";


--
-- TOC entry 110 (OID 17337)
-- Name: access; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE "access" (
    id integer DEFAULT nextval('"access_id_seq"'::text) NOT NULL,
    remotehost character(15) NOT NULL,
    usr character(15),
    "timestamp" timestamp without time zone NOT NULL,
    virtualhost character varying(64) NOT NULL,
    method character varying(8) NOT NULL,
    query character varying(255) NOT NULL,
    status smallint NOT NULL,
    bytes integer NOT NULL,
    referer character varying(1024),
    useragent character varying(128)
);


--
-- TOC entry 111 (OID 17337)
-- Name: access; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE "access" FROM PUBLIC;
GRANT ALL ON TABLE "access" TO GROUP "wikid-sens";


--
-- TOC entry 112 (OID 17340)
-- Name: tomcat_log; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE tomcat_log (
    logdata character varying(255),
    ts timestamp without time zone DEFAULT now()
) WITHOUT OIDS;


--
-- TOC entry 113 (OID 17340)
-- Name: tomcat_log; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE tomcat_log FROM PUBLIC;
GRANT ALL ON TABLE tomcat_log TO PUBLIC;
GRANT ALL ON TABLE tomcat_log TO wikidadmin;
GRANT ALL ON TABLE tomcat_log TO GROUP "wikid-sens";


--
-- TOC entry 114 (OID 17345)
-- Name: regdevice_view; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW regdevice_view AS
	 SELECT DISTINCT devicemap.id_devicemap, devicemap.deviceid, devicemap.domainid, usermap.userid, devicemap.status, usermap.creation, usermap.id_usermap, usermap.note, full_devices.client_type, usermap.last_activity as user_last_activity, full_devices.last_activity as device_last_activity
	   FROM usermap, devicemap LEFT OUTER JOIN full_devices ON (devicemap.deviceid = full_devices.deviceid)
	  WHERE devicemap.id_devicemap = usermap.id_devicemap
	  ORDER BY usermap.userid, devicemap.deviceid, devicemap.domainid, devicemap.id_devicemap, devicemap.status, usermap.creation, usermap.id_usermap;


--
-- TOC entry 115 (OID 17345)
-- Name: regdevice_view; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE regdevice_view FROM PUBLIC;
GRANT ALL ON TABLE regdevice_view TO GROUP "wikid-sens";


SET SESSION AUTHORIZATION 'tomcat';

--
-- TOC entry 41 (OID 17346)
-- Name: trial_entry_id_seq; Type: SEQUENCE; Schema: public; Owner: tomcat
--

CREATE SEQUENCE trial_entry_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


--
-- TOC entry 42 (OID 17346)
-- Name: trial_entry_id_seq; Type: ACL; Schema: public; Owner: tomcat
--

REVOKE ALL ON TABLE trial_entry_id_seq FROM PUBLIC;
GRANT ALL ON TABLE trial_entry_id_seq TO postgres;
GRANT ALL ON TABLE trial_entry_id_seq TO GROUP "wikid-sens";


--
-- TOC entry 116 (OID 17348)
-- Name: trial_entry; Type: TABLE; Schema: public; Owner: tomcat
--

CREATE TABLE trial_entry (
    id_trial_entry bigint DEFAULT nextval('"trial_entry_id_seq"'::text) NOT NULL,
    interest character varying(256),
    user_base character varying(256),
    first_name character varying(256) NOT NULL,
    last_name character varying(256) NOT NULL,
    co_name character varying(256),
    address1 character varying(256),
    address2 character varying(256),
    city character varying(256),
    state character(2),
    zip character varying(256),
    country character(2),
    phone character varying(256),
    email character varying(256) NOT NULL,
    website character varying(256),
    secure_code character varying(256) NOT NULL,
    status character(1) DEFAULT 'Y'::bpchar NOT NULL,
    create_date date DEFAULT ('now'::text)::date NOT NULL
);


--
-- TOC entry 117 (OID 17348)
-- Name: trial_entry; Type: ACL; Schema: public; Owner: tomcat
--

REVOKE ALL ON TABLE trial_entry FROM PUBLIC;
GRANT ALL ON TABLE trial_entry TO postgres;
GRANT ALL ON TABLE trial_entry TO GROUP "wikid-sens";


SET SESSION AUTHORIZATION 'postgres';

--
-- TOC entry 43 (OID 197623)
-- Name: cryptotype_id_crytotype_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE cryptotype_id_crytotype_seq
    START WITH 1
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


--
-- TOC entry 120 (OID 197625)
-- Name: cryptotype; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE cryptotype (
    id_cryptotype integer DEFAULT nextval('"cryptotype_id_crytotype_seq"'::text) NOT NULL,
    keyalg character varying(64) NOT NULL,
    ciphertransformation character varying(128) NOT NULL
);


--
-- TOC entry 121 (OID 197625)
-- Name: cryptotype; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE cryptotype FROM PUBLIC;
GRANT SELECT ON TABLE cryptotype TO wikidadmin;


--
-- TOC entry 122 (OID 197717)
-- Name: full_domain_keys; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE full_domain_keys (
    id_domain bigint NOT NULL,
    id_cryptotype integer NOT NULL,
    dompublickey bytea NOT NULL,
    domprivatekey bytea NOT NULL,
    domkeysize integer NOT NULL,
    offlinekeysize integer NOT NULL,
    deleted boolean DEFAULT false NOT NULL
);


--
-- TOC entry 123 (OID 197737)
-- Name: domain_keys; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW domain_keys AS
    SELECT full_domain_keys.id_domain, full_domain_keys.id_cryptotype, full_domain_keys.dompublickey, full_domain_keys.domprivatekey, full_domain_keys.domkeysize, full_domain_keys.offlinekeysize FROM full_domain_keys WHERE (full_domain_keys.deleted = false);


--
-- TOC entry 124 (OID 197737)
-- Name: domain_keys; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE domain_keys FROM PUBLIC;
GRANT ALL ON TABLE domain_keys TO wikidadmin;


--
-- TOC entry 125 (OID 198931)
-- Name: devices; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW devices AS
	SELECT full_devices.id_devices, full_devices.deviceid, full_devices.ckey, full_devices.lockcode, full_devices.id_cryptotype, full_devices.init_expire, full_devices.creation, full_devices.client_type, full_devices.last_activity
	   FROM full_devices
	  WHERE full_devices.deleted = false;
ALTER TABLE devices ALTER COLUMN id_devices SET DEFAULT nextval('"devices_id_devices_seq"'::text);
ALTER TABLE devices ALTER COLUMN creation SET DEFAULT now();

--
-- TOC entry 126 (OID 198931)
-- Name: devices; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE devices FROM PUBLIC;
GRANT SELECT,UPDATE,DELETE ON TABLE devices TO wikidncserver;
GRANT SELECT,UPDATE,DELETE ON TABLE devices TO timecop;
GRANT ALL ON TABLE devices TO wikidadmin;


--
-- Name: logging_event_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE logging_event_id_seq
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


ALTER TABLE public.logging_event_id_seq OWNER TO postgres;

--
-- Name: logging_event_id_seq; Type: SEQUENCE SET; Schema: public; Owner: postgres
--

SELECT pg_catalog.setval('logging_event_id_seq', 1, true);


--
-- Name: logging_event; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE logging_event (
    sequence_number bigint NOT NULL,
    "timestamp" bigint NOT NULL,
    rendered_message text NOT NULL,
    logger_name character varying(254) NOT NULL,
    level_string character varying(254) NOT NULL,
    ndc text,
    thread_name character varying(254),
    reference_flag smallint,
    caller_filename character varying(254) NOT NULL,
    caller_class character varying(254) NOT NULL,
    caller_method character varying(254) NOT NULL,
    caller_line character(4) NOT NULL,
    event_id integer DEFAULT nextval('logging_event_id_seq'::regclass) NOT NULL
);


ALTER TABLE public.logging_event OWNER TO postgres;

--
-- Name: logging_event_exception; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE logging_event_exception (
    event_id integer NOT NULL,
    i smallint NOT NULL,
    trace_line character varying(254) NOT NULL
);


ALTER TABLE public.logging_event_exception OWNER TO postgres;

--
-- Name: logging_event_property; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE logging_event_property (
    event_id integer NOT NULL,
    mapped_key character varying(254) NOT NULL,
    mapped_value character varying(1024)
);


ALTER TABLE public.logging_event_property OWNER TO postgres;


	CREATE TABLE saml_consumers
	(
		id serial,
		service_url character varying(256), 
		p_name_target character varying(256), 
		p_name_artifact  character varying(256),
		target_url character varying(256)
	);

	CREATE TABLE saml_sessions 
	(
		id serial,
		created_at timestamp DEFAULT NOW(),
		artifact TEXT, 
		id_user integer, 
		expired_at timestamp, 
		consumer_id integer, 
		subject_ip character varying(255)
	);

-- Pre-Registration

-- add support for pre=registration and embedded registration ids

    -- Add tables for pre-registration support
    CREATE SEQUENCE id_pre_registration_seq
      INCREMENT 1
      MINVALUE 1
      MAXVALUE 9223372036854775807
      START 3
      CACHE 1;
    ALTER TABLE id_pre_registration_seq OWNER TO postgres;
    GRANT ALL ON TABLE id_pre_registration_seq TO postgres;
    GRANT ALL ON TABLE id_pre_registration_seq TO wikidncserver;
    GRANT ALL ON TABLE id_pre_registration_seq TO public;

    CREATE TABLE pre_registration
    (
      id_pre_registration bigint NOT NULL DEFAULT nextval(('"id_pre_registration_seq"'::text)::regclass),
      id_usermap bigint DEFAULT (-1),
      temp_name character varying(255) NOT NULL,
      pre_registration_code character(25) NOT NULL,
      email_address character varying(255) NOT NULL,
      creation bigint NOT NULL DEFAULT (-1),
      id_domain bigint NOT NULL DEFAULT (-1),
      CONSTRAINT pk_pre_registration PRIMARY KEY (id_pre_registration)
    );
    ALTER TABLE pre_registration OWNER TO postgres;
    GRANT ALL ON TABLE pre_registration TO postgres;
    GRANT ALL ON TABLE pre_registration TO wikidncserver;
    GRANT ALL ON TABLE pre_registration TO wikidadmin;


-- Groups

    CREATE SEQUENCE id_group_radius_attrib_seq
      INCREMENT 1
      MINVALUE 1
      MAXVALUE 9223372036854775807
      START 12
      CACHE 1;
    ALTER TABLE id_group_radius_attrib_seq OWNER TO postgres;
    GRANT ALL ON TABLE id_group_radius_attrib_seq TO postgres;
    GRANT ALL ON TABLE id_group_radius_attrib_seq TO public;


    CREATE SEQUENCE id_user_group_map_seq
      INCREMENT 1
      MINVALUE 1
      MAXVALUE 9223372036854775807
      START 5
      CACHE 1;
    ALTER TABLE id_user_group_map_seq OWNER TO postgres;
    GRANT ALL ON TABLE id_user_group_map_seq TO postgres;
    GRANT ALL ON TABLE id_user_group_map_seq TO public;

    CREATE SEQUENCE id_wikid_group_seq
      INCREMENT 1
      MINVALUE 1
      MAXVALUE 9223372036854775807
      START 8
      CACHE 1;
    ALTER TABLE id_wikid_group_seq OWNER TO postgres;
    GRANT ALL ON TABLE id_wikid_group_seq TO postgres;
    GRANT ALL ON TABLE id_wikid_group_seq TO public;


    CREATE TABLE wikid_group
    (
      id_wikid_group bigint NOT NULL DEFAULT nextval(('"id_wikid_group_seq"'::text)::regclass),
      group_name character varying(255) NOT NULL,
      precedence integer NOT NULL DEFAULT -1,
      CONSTRAINT wikid_group_pk PRIMARY KEY (id_wikid_group)
    );
    ALTER TABLE wikid_group OWNER TO postgres;
    GRANT ALL ON TABLE wikid_group TO postgres;
    GRANT ALL ON TABLE wikid_group TO public;

    CREATE TABLE user_group_map
    (
      id_user_group_map bigint NOT NULL DEFAULT nextval(('"id_user_group_map_seq"'::text)::regclass),
      id_usermap bigint NOT NULL,
      id_wikid_group bigint NOT NULL,
      CONSTRAINT id_user_group_map_pk PRIMARY KEY (id_user_group_map)
    );
    ALTER TABLE user_group_map OWNER TO postgres;
    GRANT ALL ON TABLE user_group_map TO postgres;
    GRANT ALL ON TABLE user_group_map TO public;

    CREATE TABLE group_radius_attrib
    (
      id_group_radius_attrib bigint NOT NULL DEFAULT nextval(('"id_group_radius_attrib_seq"'::text)::regclass),
      id_wikid_group bigint NOT NULL,
      akey character(100) NOT NULL,
      avalue character varying(255) NOT NULL,
      vendor_id integer,
      CONSTRAINT id_group_radius_attrib_pk PRIMARY KEY (id_group_radius_attrib),
      CONSTRAINT "$1" FOREIGN KEY (id_wikid_group)
          REFERENCES wikid_group (id_wikid_group) MATCH SIMPLE
          ON UPDATE NO ACTION ON DELETE NO ACTION
    );    
    ALTER TABLE group_radius_attrib OWNER TO postgres;
    GRANT ALL ON TABLE group_radius_attrib TO postgres;
    GRANT ALL ON TABLE group_radius_attrib TO public;


-- Google SSO

    CREATE SEQUENCE id_gsso_app_domain_map_seq
      INCREMENT 1
      MINVALUE 1
      MAXVALUE 9223372036854775807
      START 5
      CACHE 1;
    ALTER TABLE id_gsso_app_domain_map_seq OWNER TO postgres;
    GRANT ALL ON TABLE id_gsso_app_domain_map_seq TO postgres;
    GRANT ALL ON TABLE id_gsso_app_domain_map_seq TO public;

    CREATE TABLE gsso_app_domain_map
    (
        id_gsso_app_domain_map bigint NOT NULL DEFAULT nextval(('"id_gsso_app_domain_map_seq"'::text)::regclass),
        id_nc bigint NOT NULL,
        acs_url character varying(255) NOT NULL,
        CONSTRAINT id_gsso_app_domain_map_pk PRIMARY KEY (id_gsso_app_domain_map)
    );
    ALTER TABLE gsso_app_domain_map OWNER TO postgres;
    GRANT ALL ON TABLE gsso_app_domain_map TO postgres;
    GRANT ALL ON TABLE gsso_app_domain_map TO public;


--
-- TOC entry 157 (OID 17359)
-- Name: access_id_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE UNIQUE INDEX access_id_key ON "access" USING btree (id);


--
-- TOC entry 160 (OID 17360)
-- Name: access_timestamp_idx; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX access_timestamp_idx ON "access" USING btree ("timestamp");


--
-- TOC entry 159 (OID 17361)
-- Name: access_status_idx; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX access_status_idx ON "access" USING btree (status);


--
-- TOC entry 161 (OID 17362)
-- Name: tomcat_log_ts_idx; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX tomcat_log_ts_idx ON tomcat_log USING btree (ts);


--
-- TOC entry 142 (OID 17363)
-- Name: host_nc_map_id_hostncmap_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE UNIQUE INDEX host_nc_map_id_hostncmap_key ON host_nc_map USING btree (id_hostncmap);


--
-- TOC entry 143 (OID 17364)
-- Name: host_subtype_id_hostsubtype_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE UNIQUE INDEX host_subtype_id_hostsubtype_key ON host_subtype USING btree (id_hostsubtype);


--
-- TOC entry 144 (OID 17365)
-- Name: host_type_id_hosttype_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE UNIQUE INDEX host_type_id_hosttype_key ON host_type USING btree (id_hosttype);

CREATE UNIQUE INDEX unique_type
  ON host_type
  USING btree
  (type);

--
-- TOC entry 139 (OID 17366)
-- Name: network_client_id_nc_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE UNIQUE INDEX network_client_id_nc_key ON full_network_client USING btree (id_nc);


--
-- TOC entry 145 (OID 17367)
-- Name: usr_id_user_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE UNIQUE INDEX usr_id_user_key ON usr USING btree (id_user);


--
-- TOC entry 140 (OID 17368)
-- Name: host_id_host_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE UNIQUE INDEX host_id_host_key ON host USING btree (id_host);


--
-- TOC entry 146 (OID 17369)
-- Name: profile_id_profile_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE UNIQUE INDEX profile_id_profile_key ON profile USING btree (id_profile);


--
-- TOC entry 127 (OID 17370)
-- Name: dom_unq_code_ndx; Type: INDEX; Schema: public; Owner: postgres
--

CREATE UNIQUE INDEX dom_unq_code_ndx ON full_domain USING btree (code) WHERE (deleted = false);


--
-- TOC entry 137 (OID 136628)
-- Name: usermap_id_usermap_ndx; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX usermap_id_usermap_ndx ON full_usermap USING btree (id_usermap);


--
-- TOC entry 135 (OID 139129)
-- Name: usermap_id_devicemap_ndx; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX usermap_id_devicemap_ndx ON full_usermap USING btree (id_devicemap);


--
-- TOC entry 136 (OID 141630)
-- Name: usermap_id_userid_ndx; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX usermap_id_userid_ndx ON full_usermap USING btree (userid);


--
-- TOC entry 131 (OID 144131)
-- Name: devicemap_id_devicemap_ndx; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX devicemap_id_devicemap_ndx ON full_devicemap USING btree (id_devicemap);


--
-- TOC entry 130 (OID 147575)
-- Name: devicemap_id_deviceid_ndx; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX devicemap_id_deviceid_ndx ON full_devicemap USING btree (deviceid);


--
-- TOC entry 129 (OID 148579)
-- Name: devicemap_domainid_ndx; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX devicemap_domainid_ndx ON full_devicemap USING btree (domainid);


--
-- TOC entry 148 (OID 149583)
-- Name: devices_id_devices_ndx; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX devices_id_devices_ndx ON full_devices USING btree (id_devices);


--
-- TOC entry 147 (OID 150587)
-- Name: devices_deviceid_ndx; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX devices_deviceid_ndx ON full_devices USING btree (deviceid);


--
-- TOC entry 164 (OID 197630)
-- Name: cryptotype_unq_row_ndx; Type: INDEX; Schema: public; Owner: postgres
--

CREATE UNIQUE INDEX cryptotype_unq_row_ndx ON cryptotype USING btree (keyalg, ciphertransformation);


--
-- TOC entry 165 (OID 197768)
-- Name: dom_keys_unq_dom_keytype_ndx; Type: INDEX; Schema: public; Owner: postgres
--

CREATE UNIQUE INDEX dom_keys_unq_dom_keytype_ndx ON full_domain_keys USING btree (id_domain, id_cryptotype) WHERE (deleted = false);


CREATE INDEX devicemap_perf1_ndx ON full_devicemap USING btree (deviceid, domainid, status);

--
-- TOC entry 128 (OID 17371)
-- Name: full_domain_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY full_domain
    ADD CONSTRAINT full_domain_pkey PRIMARY KEY (id_domain);


--
-- TOC entry 132 (OID 17373)
-- Name: full_devicemap_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY full_devicemap
    ADD CONSTRAINT full_devicemap_pkey PRIMARY KEY (id_devicemap);


--
-- TOC entry 133 (OID 17375)
-- Name: pkey_curr_codes; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY curr_codes
    ADD CONSTRAINT pkey_curr_codes PRIMARY KEY (id_curr_codes);


--
-- TOC entry 134 (OID 17377)
-- Name: full_usermap_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY full_usermap
    ADD CONSTRAINT full_usermap_pkey PRIMARY KEY (id_usermap);


--
-- TOC entry 138 (OID 17379)
-- Name: full_network_client_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY full_network_client
    ADD CONSTRAINT full_network_client_pkey PRIMARY KEY (id_nc);


--
-- TOC entry 141 (OID 17381)
-- Name: host_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY host
    ADD CONSTRAINT host_pkey PRIMARY KEY (id_host);


--
-- TOC entry 149 (OID 17383)
-- Name: full_devices_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY full_devices
    ADD CONSTRAINT full_devices_pkey PRIMARY KEY (id_devices);


--
-- TOC entry 150 (OID 17385)
-- Name: help_links_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY help_links
    ADD CONSTRAINT help_links_pkey PRIMARY KEY (link);


--
-- TOC entry 151 (OID 17387)
-- Name: parms1to1_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY parms1to1
    ADD CONSTRAINT parms1to1_pkey PRIMARY KEY ("key");


--
-- TOC entry 152 (OID 17389)
-- Name: cert_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY cert
    ADD CONSTRAINT cert_pkey PRIMARY KEY (id_cert);


--
-- TOC entry 156 (OID 17397)
-- Name: pk_tempregcodes; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY tempregcodes
    ADD CONSTRAINT pk_tempregcodes PRIMARY KEY (id_tempregcodes);


--
-- TOC entry 158 (OID 17399)
-- Name: access_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY "access"
    ADD CONSTRAINT access_pkey PRIMARY KEY (id);


SET SESSION AUTHORIZATION 'tomcat';

--
-- TOC entry 162 (OID 17401)
-- Name: pk_trial_entry; Type: CONSTRAINT; Schema: public; Owner: tomcat
--

ALTER TABLE ONLY trial_entry
    ADD CONSTRAINT pk_trial_entry PRIMARY KEY (id_trial_entry);


SET SESSION AUTHORIZATION 'postgres';

--
-- TOC entry 163 (OID 197628)
-- Name: cryptotype_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY cryptotype
    ADD CONSTRAINT cryptotype_pkey PRIMARY KEY (id_cryptotype);


--
-- TOC entry 173 (OID 17403)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY full_devicemap
    ADD CONSTRAINT "$1" FOREIGN KEY (domainid) REFERENCES full_domain(id_domain);


--
-- TOC entry 174 (OID 17407)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY curr_codes
    ADD CONSTRAINT "$1" FOREIGN KEY (id_devicemap) REFERENCES full_devicemap(id_devicemap);


--
-- TOC entry 175 (OID 17411)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY full_usermap
    ADD CONSTRAINT "$1" FOREIGN KEY (id_devicemap) REFERENCES full_devicemap(id_devicemap);


--
-- TOC entry 176 (OID 17415)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY full_network_client
    ADD CONSTRAINT "$1" FOREIGN KEY ("domain") REFERENCES full_domain(id_domain);


--
-- TOC entry 177 (OID 17419)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY host_nc_map
    ADD CONSTRAINT "$1" FOREIGN KEY (host) REFERENCES host(id_host);


--
-- TOC entry 178 (OID 17423)
-- Name: $2; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY host_nc_map
    ADD CONSTRAINT "$2" FOREIGN KEY (nc) REFERENCES full_network_client(id_nc);


--
-- TOC entry 180 (OID 17427)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY nc_return_attrib
    ADD CONSTRAINT "$1" FOREIGN KEY (id_nc) REFERENCES full_network_client(id_nc);


--
-- TOC entry 181 (OID 17431)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY cert
    ADD CONSTRAINT "$1" FOREIGN KEY (id_nc) REFERENCES full_network_client(id_nc);


--
-- TOC entry 188 (OID 17459)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY tempregcodes
    ADD CONSTRAINT "$1" FOREIGN KEY (id_devicemap) REFERENCES full_devicemap(id_devicemap);


--
-- TOC entry 189 (OID 197723)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY full_domain_keys
    ADD CONSTRAINT "$1" FOREIGN KEY (id_domain) REFERENCES full_domain(id_domain);


--
-- TOC entry 190 (OID 197727)
-- Name: $2; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY full_domain_keys
    ADD CONSTRAINT "$2" FOREIGN KEY (id_cryptotype) REFERENCES cryptotype(id_cryptotype);


--
-- TOC entry 179 (OID 198850)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY full_devices
    ADD CONSTRAINT "$1" FOREIGN KEY (id_cryptotype) REFERENCES cryptotype(id_cryptotype);

--
-- Name: logging_event_exception_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY logging_event_exception
    ADD CONSTRAINT logging_event_exception_pkey PRIMARY KEY (event_id, i);


--
-- Name: logging_event_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY logging_event
    ADD CONSTRAINT logging_event_pkey PRIMARY KEY (event_id);


--
-- Name: logging_event_property_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY logging_event_property
    ADD CONSTRAINT logging_event_property_pkey PRIMARY KEY (event_id, mapped_key);


--
-- TOC entry 191 (OID 17463)
-- Name: domain_delete_trigger; Type: TRIGGER; Schema: public; Owner: postgres
--

CREATE TRIGGER domain_delete_trigger
    BEFORE UPDATE ON full_domain
    FOR EACH ROW
    EXECUTE PROCEDURE domain_delete_func();


--
-- TOC entry 192 (OID 17464)
-- Name: devicemap_delete_trigger; Type: TRIGGER; Schema: public; Owner: postgres
--

CREATE TRIGGER devicemap_delete_trigger
    BEFORE UPDATE ON full_devicemap
    FOR EACH ROW
    EXECUTE PROCEDURE devicemap_delete_func();


--
-- TOC entry 193 (OID 17465)
-- Name: usermap_delete_trigger; Type: TRIGGER; Schema: public; Owner: postgres
--

CREATE TRIGGER usermap_delete_trigger
    BEFORE UPDATE ON full_usermap
    FOR EACH ROW
    EXECUTE PROCEDURE usermap_delete_func();


--
-- TOC entry 194 (OID 17466)
-- Name: network_client_delete_trigger; Type: TRIGGER; Schema: public; Owner: postgres
--

CREATE TRIGGER network_client_delete_trigger
    BEFORE UPDATE ON full_network_client
    FOR EACH ROW
    EXECUTE PROCEDURE network_client_delete_func();


--
-- TOC entry 195 (OID 17467)
-- Name: devices_delete_trigger; Type: TRIGGER; Schema: public; Owner: postgres
--

CREATE TRIGGER devices_delete_trigger
    BEFORE UPDATE ON full_devices
    FOR EACH ROW
    EXECUTE PROCEDURE devices_delete_func();


--
-- TOC entry 196 (OID 17468)
-- Name: domain_insert_rule; Type: RULE; Schema: public; Owner: postgres
--

CREATE RULE domain_insert_rule AS ON INSERT TO "domain" DO INSTEAD INSERT INTO full_domain (id_domain, code, name, ddname, registered_url, registered_url_hash, minpin, "valid", maxbads, maxoffs, lockrequired, clients_allowed, tacacs, maxattempts, publickey, privatekey, creation, reset_domain, nt_host, admin_user, admin_passwd, nt_domain_name, deleted) VALUES (new.id_domain, new.code, new.name, new.ddname, new.registered_url, new.registered_url_hash, new.minpin, new."valid", new.maxbads, new.maxoffs, new.lockrequired, new.clients_allowed, new.tacacs, new.maxattempts, new.publickey, new.privatekey, new.creation, new.reset_domain, new.nt_host, new.admin_user, new.admin_passwd, new.nt_domain_name, false);


--
-- TOC entry 197 (OID 17469)
-- Name: domain_update_rule; Type: RULE; Schema: public; Owner: postgres
--

CREATE RULE domain_update_rule AS ON UPDATE TO "domain" DO INSTEAD UPDATE full_domain SET id_domain = new.id_domain, code = new.code, name = new.name, ddname = new.ddname, registered_url = new.registered_url, registered_url_hash = new.registered_url_hash, minpin = new.minpin, "valid" = new."valid", maxbads = new.maxbads, maxoffs = new.maxoffs, lockrequired = new.lockrequired, clients_allowed = new.clients_allowed, tacacs = new.tacacs, maxattempts = new.maxattempts, publickey = new.publickey, privatekey = new.privatekey, creation = new.creation, reset_domain = new.reset_domain, nt_host = new.nt_host, admin_user = new.admin_user, admin_passwd = new.admin_passwd, nt_domain_name = new.nt_domain_name WHERE (full_domain.id_domain = old.id_domain);


--
-- TOC entry 198 (OID 17470)
-- Name: domain_delete_rule; Type: RULE; Schema: public; Owner: postgres
--

CREATE RULE domain_delete_rule AS ON DELETE TO "domain" DO INSTEAD UPDATE full_domain SET deleted = true WHERE (full_domain.id_domain = old.id_domain);


--
-- TOC entry 199 (OID 17471)
-- Name: devicemap_insert_rule; Type: RULE; Schema: public; Owner: postgres
--

CREATE OR REPLACE RULE devicemap_insert_rule AS
    ON INSERT TO devicemap DO INSTEAD  INSERT INTO full_devicemap (id_devicemap, deviceid, domainid, pin, offkeypub, offkeypriv, status, bads, offs, init_expire, creation, deleted, disable_date)
  VALUES (new.id_devicemap, new.deviceid, new.domainid, new.pin, new.offkeypub, new.offkeypriv, new.status, new.bads, new.offs, new.init_expire, new.creation, false, new.disable_date);


--
-- TOC entry 200 (OID 17472)
-- Name: devicemap_update_rule; Type: RULE; Schema: public; Owner: postgres
--

CREATE OR REPLACE RULE devicemap_update_rule AS
    ON UPDATE TO devicemap DO INSTEAD  UPDATE full_devicemap SET id_devicemap = new.id_devicemap, deviceid = new.deviceid, domainid = new.domainid, pin = new.pin,
	offkeypub = new.offkeypub, offkeypriv = new.offkeypriv, status = new.status, bads = new.bads, offs = new.offs, init_expire = new.init_expire, creation = new.creation, disable_date = new.disable_date, disable_cause = new.disable_cause
  WHERE full_devicemap.id_devicemap = old.id_devicemap;


--
-- TOC entry 201 (OID 17473)
-- Name: devicemap_delete_rule; Type: RULE; Schema: public; Owner: postgres
--

CREATE RULE devicemap_delete_rule AS ON DELETE TO devicemap DO INSTEAD UPDATE full_devicemap SET deleted = true WHERE (full_devicemap.id_devicemap = old.id_devicemap);


--
-- TOC entry 202 (OID 17474)
-- Name: usermap_insert_rule; Type: RULE; Schema: public; Owner: postgres
--

CREATE OR REPLACE RULE usermap_insert_rule AS
    ON INSERT TO usermap DO INSTEAD  INSERT INTO full_usermap (id_usermap, id_devicemap, userid, bads, creation, status, note, last_activity, deleted, disable_date)
  VALUES (new.id_usermap, new.id_devicemap, new.userid, new.bads, new.creation, new.status, new.note, new.last_activity, false, new.disable_date);

--
-- TOC entry 203 (OID 17475)
-- Name: usermap_update_rule; Type: RULE; Schema: public; Owner: postgres
--

CREATE OR REPLACE RULE usermap_update_rule AS
    ON UPDATE TO usermap DO INSTEAD  UPDATE full_usermap SET id_usermap = new.id_usermap, id_devicemap = new.id_devicemap, userid = new.userid, bads = new.bads, 
    creation = new.creation, status = new.status, note = new.note, last_activity = new.last_activity, disable_date = new.disable_date, disable_cause = new.disable_cause
  WHERE full_usermap.id_usermap = old.id_usermap;

--
-- TOC entry 204 (OID 17476)
-- Name: usermap_delete_rule; Type: RULE; Schema: public; Owner: postgres
--

CREATE RULE usermap_delete_rule AS ON DELETE TO usermap DO INSTEAD UPDATE full_usermap SET deleted = true WHERE (full_usermap.id_usermap = old.id_usermap);


--
-- TOC entry 205 (OID 17477)
-- Name: network_client_insert_rule; Type: RULE; Schema: public; Owner: postgres
--

CREATE RULE network_client_insert_rule AS ON INSERT TO network_client DO INSTEAD INSERT INTO full_network_client (id_nc, ip, name, secret, enforced, "domain", creation, deleted) VALUES (new.id_nc, new.ip, new.name, new.secret, new.enforced, new."domain", new.creation, false);


--
-- TOC entry 206 (OID 17478)
-- Name: network_client_update_rule; Type: RULE; Schema: public; Owner: postgres
--

CREATE RULE network_client_update_rule AS ON UPDATE TO network_client DO INSTEAD UPDATE full_network_client SET id_nc = new.id_nc, ip = new.ip, name = new.name, secret = new.secret, enforced = new.enforced, "domain" = new."domain", creation = new.creation WHERE (full_network_client.id_nc = old.id_nc);


--
-- TOC entry 207 (OID 17479)
-- Name: network_client_delete_rule; Type: RULE; Schema: public; Owner: postgres
--

CREATE RULE network_client_delete_rule AS ON DELETE TO network_client DO INSTEAD UPDATE full_network_client SET deleted = true WHERE (full_network_client.id_nc = old.id_nc);


--
-- TOC entry 208 (OID 197740)
-- Name: domain_keys_insert_rule; Type: RULE; Schema: public; Owner: postgres
--

CREATE RULE domain_keys_insert_rule AS ON INSERT TO domain_keys DO INSTEAD INSERT INTO full_domain_keys (id_domain, id_cryptotype, dompublickey, domprivatekey, domkeysize, offlinekeysize, deleted) VALUES (new.id_domain, new.id_cryptotype, new.dompublickey, new.domprivatekey, new.domkeysize, new.offlinekeysize, false);


--
-- TOC entry 198 (OID 17470)
-- Name: domain_delete_rule; Type: RULE; Schema: public; Owner: postgres
--

CREATE RULE domain_keys_delete_rule AS ON DELETE TO "domain_keys" DO INSTEAD UPDATE full_domain_keys SET deleted = true WHERE (full_domain_keys.id_domain = old.id_domain);

--
-- TOC entry 209 (OID 198934)
-- Name: devices_insert_rule; Type: RULE; Schema: public; Owner: postgres
--

CREATE RULE devices_insert_rule AS ON INSERT TO devices DO INSTEAD  INSERT INTO full_devices (id_devices, deviceid, ckey, id_cryptotype, lockcode, init_expire, creation, client_type, last_activity, deleted) 
	  VALUES (new.id_devices, new.deviceid, new.ckey, new.id_cryptotype, new.lockcode, new.init_expire, new.creation, new.client_type, new.last_activity, false);


--
-- TOC entry 210 (OID 198935)
-- Name: devices_update_rule; Type: RULE; Schema: public; Owner: postgres
--

CREATE RULE devices_update_rule AS ON UPDATE TO devices DO INSTEAD  UPDATE full_devices SET id_devices = new.id_devices, deviceid = new.deviceid, ckey = new.ckey, id_cryptotype = new.id_cryptotype, lockcode = new.lockcode, init_expire = new.init_expire, creation = new.creation, client_type = new.client_type, last_activity = new.last_activity
	  WHERE full_devices.id_devices = old.id_devices;

--
-- TOC entry 211 (OID 198936)
-- Name: devices_delete_rule; Type: RULE; Schema: public; Owner: postgres
--

CREATE RULE devices_delete_rule AS ON DELETE TO devices DO INSTEAD UPDATE full_devices SET deleted = true WHERE (full_devices.id_devices = old.id_devices);

--
-- Name: logging_event; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE logging_event FROM PUBLIC;
REVOKE ALL ON TABLE logging_event FROM postgres;
GRANT ALL ON TABLE logging_event TO postgres;
GRANT ALL ON TABLE logging_event TO "wikid-sens";


--
-- Name: logging_event_exception; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE logging_event_exception FROM PUBLIC;
REVOKE ALL ON TABLE logging_event_exception FROM postgres;
GRANT ALL ON TABLE logging_event_exception TO postgres;
GRANT ALL ON TABLE logging_event_exception TO "wikid-sens";


--
-- Name: logging_event_property; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE logging_event_property FROM PUBLIC;
REVOKE ALL ON TABLE logging_event_property FROM postgres;
GRANT ALL ON TABLE logging_event_property TO postgres;
GRANT ALL ON TABLE logging_event_property TO "wikid-sens";



--
-- TOC entry 3 (OID 2200)
-- Name: SCHEMA public; Type: COMMENT; Schema: -; Owner: postgres
--

COMMENT ON SCHEMA public IS 'Standard public schema';


--
-- TOC entry 86 (OID 17287)
-- Name: TABLE parms1to1; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON TABLE parms1to1 IS 'Generic key=value config table';


--
-- TOC entry 87 (OID 17287)
-- Name: COLUMN parms1to1.hide; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON COLUMN parms1to1.hide IS 'Determines whether the value is masked in the admin system.';


SET SESSION AUTHORIZATION 'tomcat';

--
-- Fix a permissions issue that was causing timecop to lose the tacacs secret
--


SET SESSION AUTHORIZATION 'postgres';

GRANT ALL ON TABLE network_client TO timecop;
GRANT ALL ON TABLE host_nc_map TO timecop;
GRANT ALL ON TABLE host TO timecop;

