#!/usr/bin/perl -w
use strict;
use lib '/opt/WiKID/lib';
use WiKIDUpdate;
use Getopt::Long;

sub usage() {
   print STDERR "Usage: $0 release build\n";
   print STDERR "  release: The aready-downloaded release to install (such as 1.0)\n";
   print STDERR "  build: The already-downloaded build of the release to install\n";
   print STDERR "This installs an update that has already been downloaded.\n";
   exit 1;
}

&usage() unless ($#ARGV >= 1);

my $Force = 0;
my $NoRollback = 0;
my $Help = 0;
GetOptions (
   'h|help' => \$Help,
   'f|force' => \$Force,
   'n|norollback' => \$NoRollback
   ) or &usage();
$Help and &usage();

my $changed = 0;
my @rpm_opts = ();
if ($Force) {
   push @rpm_opts, '--force';
}

my $release = $ARGV[0];
my $build = $ARGV[1];

sub mydie {
   print STDERR "\n", $_[0] . "\n";
   if ($changed) {
      if ($NoRollback) {
         print STDERR "\nAn error has occurred, skipping rollback as instructed.\n\n";
      } else {
         print STDERR "\nAn error has occurred, rolling back to original version ($WiKIDUpdate::release build $WiKIDUpdate::build)\n\n";
         system('/opt/WiKID/sbin/perform_rollback.pl', $WiKIDUpdate::release, $WiKIDUpdate::build, $release, $build);
      }
   } else {
      print STDERR "\nAn error has occurred before any changes were made, so no rollback is necessary.\n\n";
   }
   exit 1;
}

unless (system("rpm -q gpg-pubkey-4f2a6fd2-3f9d9d3b >/dev/null 2>&1") == 0) {
   print "Importing GPG Key '4f2a6fd2-3f9d9d3b'... ";
   system("rpm --import /usr/share/doc/fedora-release-1/RPM-GPG-KEY-fedora");
   print "Done.\n"
}

unless (&WiKIDUpdate::verify_update_dir("/opt/WiKID/var/update/update-$release-$build")) {
   die "Update to $release build $build has not been completely downloaded or is outdated.\n";
}

# Create rollback archive file
unless (system('/opt/WiKID/sbin/create_checkpoint.pl', $release, $build) == 0) {
   die "Could not create checkpoint to allow for rollback, aborting upgrade.\n";
}
print "\n";

my @remove_list = &::WiKIDUpdate::read_file("/opt/WiKID/var/update/update-$release-$build/upgrade_remove");
if (@remove_list) {
   print "Removing unneeded RPMs...\n";
   my $ret = &::WiKIDUpdate::remove_packages(@remove_list);
   if ($ret == 0) {
      mydie "Could not remove one or more RPMs that need to be removed.";
   } elsif ($ret == 1) {
      $changed++;
   }
}

print "Upgrading/installing new RPMs...\n";
my $ret = &::WiKIDUpdate::install_directory("/opt/WiKID/var/update/update-$release-$build/upgrade_rpms", @rpm_opts);
if ($ret == 0) {
   mydie "Could not install or upgrade all necessary RPMs.";
} elsif ($ret == 1) {
   $changed++;
}

if (-s "/opt/WiKID/var/update/update-$release-$build/upgrade_script") {
   print "Executing upgrade scripts...\n";
   $changed++;
   unless (system('bash', "/opt/WiKID/var/update/update-$release-$build/upgrade_script") == 0) {
      mydie "There were errors running the upgrade scripts.";
   }
}

# Re-apply system configuration
print "\nRe-configuring your system...\n";
system("/opt/WiKID/sbin/reconfig.sh");
print "Done.\n\n";

&::WiKIDUpdate::record_release_build($release, $build);

system('rm', '-rf', "/opt/WiKID/var/update/update-$release-$build");

print "Upgrade to $release build $build is complete.\n"

