#!/usr/bin/perl -w
use strict;
use lib '/opt/WiKID/lib';
use WiKIDUpdate;

sub usage() {
   print STDERR "Usage: $0 [release build]\n";
   print STDERR "This archives the current state of the system for future\n";
   print STDERR "recovery.  An optional release and build is provided if this\n";
   print STDERR "state is being saved because of an upcoming upgrade.\n";
   exit 1;
}

&usage() if ($ARGV[0] and ($ARGV[0] eq '--help'));

my $release = $ARGV[0];
my $build = $ARGV[1];
my $archive_in_file = "/opt/WiKID/var/update/archive_list";
my $rollbackdir = "/opt/WiKID/var/update/rollback-$WiKIDUpdate::release-$WiKIDUpdate::build";
my $time = time;
my $archive_out_file = "$rollbackdir/archive-$time.tgz";
mkdir $rollbackdir;

if ($release and $build) {
   unless (&WiKIDUpdate::verify_update_dir("/opt/WiKID/var/update/update-$release-$build")) {
      die "Update to $release build $build has not been completely downloaded or is outdated.\n";
   }
   $archive_in_file = "/opt/WiKID/var/update/update-$release-$build/archive_list";
   $archive_out_file = "$rollbackdir/archive-before-$release-$build.tgz";
}

# Create rollback archive file
print "Creating archive file...\n";
chdir('/');
my @archive_list = &::WiKIDUpdate::read_file($archive_in_file);
foreach (@archive_list) {
   s/^\///;
}
system('tar', '--exclude', 'opt/WiKID/var/update', '-czpf', $archive_out_file, @archive_list);

unless ($release and $build) {
   print "Checkpoint for $WiKIDUpdate::release build $WiKIDUpdate::build complete.\n";
   exit 0;
}

print "Storing rollback RPMs...\n";
mkdir "$rollbackdir/back-from-$release-$build";
system("cp -ar /opt/WiKID/var/update/update-$release-$build/revert_rpms/* $rollbackdir/back-from-$release-$build");
system('cp', "/opt/WiKID/var/update/update-$release-$build/downgrade_remove", "$rollbackdir/back-from-$release-$build");
system('cp', "/opt/WiKID/var/update/update-$release-$build/downgrade_script", "$rollbackdir/back-from-$release-$build");
   
print "Checkpoint from $release build $build back to $WiKIDUpdate::release build $WiKIDUpdate::build complete.\n";
exit 0;
