#!/usr/bin/perl -w
use strict;
use lib '/opt/WiKID/lib';
use WiKIDUpdate;

# Make perl flush STDOUT after each line (or print statement, I forget),
# even if STDOUT is being redirected. 
# Added this so web admin can get up-to-the-second progress on their download.
# That is, so they can immediately see what download_update prints.
# -csidi

$| = 1;


sub usage() {
   print STDERR "Usage: $0 release build passphrase\n";
   print STDERR "  release: The release to download (such as 1.0)\n";
   print STDERR "  build: The build of the release to download\n";
   print STDERR "  passphrase: The passphrase for the secondary CA cert\n";
   print STDERR "This downloads the specified build for later installation.\n";
   exit 1;
}

&usage() unless ($#ARGV == 2);

my $release = $ARGV[0];
my $build = $ARGV[1];
my $passphrase = $ARGV[2];

unless (system('/opt/WiKID/sbin/prepare_update_cert.sh', $passphrase) == 0) {
   die "Could not prepare secondary CA certificate -- does it exist and is the passphrase correct?\n";
}

&WiKIDUpdate::prepare_client_auth($passphrase);

my $archs = `rpm --showrc 2>&1 | sed -n 's/^compatible archs.*: //p'`;
chomp ($archs);
$archs =~ s/\s/+/g;

if (-d "/opt/WiKID/var/update/pending-$release-$build") {
   unless (&WiKIDUpdate::verify_update_dir("/opt/WiKID/var/update/pending-$release-$build")) {
      system("rm -rf /opt/WiKID/var/update/pending-$release-$build/*");
   }
} else {
   mkdir "/opt/WiKID/var/update/pending-$release-$build" or die "Could not create directory /opt/WiKID/var/update/pending-$release-$build: $!\n";
}
mkdir "/opt/WiKID/var/update/pending-$release-$build/upgrade_rpms";
mkdir "/opt/WiKID/var/update/pending-$release-$build/revert_rpms";
open(ORIG, ">/opt/WiKID/var/update/pending-$release-$build/orig_release") or die "Could not open /opt/WiKID/var/update/pending-$release-$build/orig_release: $!\n";
print ORIG "$WiKIDUpdate::release\n";
close(ORIG);
open(ORIG, ">/opt/WiKID/var/update/pending-$release-$build/orig_build") or die "Could not open /opt/WiKID/var/update/pending-$release-$build/orig_build: $!\n";
print ORIG "$WiKIDUpdate::build\n";
close(ORIG);
open(PID, ">/opt/WiKID/var/update/pending-$release-$build/pid") or die "Could not open /opt/WiKID/var/update/pending-$release-$build/orig_build: $!\n";
print PID "$$\n";
close(PID);
open(UPGRADE_SCRIPT, ">/opt/WiKID/var/update/pending-$release-$build/upgrade_script") or die "Could not open /opt/WiKID/var/update/pending-$release-$build/upgrade_script: $!\n";
open(DOWNGRADE_SCRIPT, ">/opt/WiKID/var/update/pending-$release-$build/downgrade_script") or die "Could not open /opt/WiKID/var/update/pending-$release-$build/downgrade_script: $!\n";
open(ARCHIVE, ">/opt/WiKID/var/update/pending-$release-$build/archive_list") or die "Could not open /opt/WiKID/var/update/pending-$release-$build/archive_list: $!\n";
open(UPGRADE, ">/opt/WiKID/var/update/pending-$release-$build/upgrade_remove") or die "Could not open /opt/WiKID/var/update/pending-$release-$build/upgrade_remove: $!\n";
open(DOWNGRADE, ">/opt/WiKID/var/update/pending-$release-$build/downgrade_remove") or die "Could not open /opt/WiKID/var/update/pending-$release-$build/downgrade_remove: $!\n";
foreach (&WiKIDUpdate::get_lines_from_server("http://updates.wikidsystems.com/wikid/servlet/com.wikidsystems.updater.update?action=get_upgrade&release=$WiKIDUpdate::release&build=$WiKIDUpdate::build&hostname=$WiKIDUpdate::hostname&ipaddr=$WiKIDUpdate::ipaddr&modulus=$WiKIDUpdate::modulus&new_release=$release&new_build=$build&archs=$archs")) {
   next if /^DEBUG: /;
   if (s/^archive: //) {
      print ARCHIVE $_;
   } elsif (s/^upgrade_script: //) {
      print UPGRADE_SCRIPT $_;
   } elsif (s/^downgrade_script: //) {
      print DOWNGRADE_SCRIPT $_;
   } elsif (/^Upgrade to $release build $build: (upgrade to|install) [^:]+: ([^]]+) \[(\d+)\]/) {
      my $source = $2;
      my $size = $3;
      my $dest = $2;
      $dest =~ s/^.*\///;
      unless (&WiKIDUpdate::get_ssl_file("https://updates.wikidsystems.com/depot/$source", "/opt/WiKID/var/update/pending-$release-$build/upgrade_rpms/$dest", $size)) {
         die "Could not download $source\n";
      }
   } elsif (s/^Upgrade to $release build $build: remove //) {
      print UPGRADE $_;
   } elsif (/^Revert to $WiKIDUpdate::release build $WiKIDUpdate::build: (downgrade to|install) [^:]+: ([^]]+) \[(\d+)\]/) {
      my $source = $2;
      my $size = $3;
      my $dest = $2;
      $dest =~ s/^.*\///;
      unless (&WiKIDUpdate::get_ssl_file("https://updates.wikidsystems.com/depot/$source", "/opt/WiKID/var/update/pending-$release-$build/revert_rpms/$dest", $size)) {
         die "Could not download $source\n";
      }
   } elsif (s/^Revert to $WiKIDUpdate::release build $WiKIDUpdate::build: remove //) {
      print DOWNGRADE $_;
   }
}
close(ARCHIVE);
close(UPGRADE);
close(DOWNGRADE);
close(UPGRADE_SCRIPT);
close(DOWNGRADE_SCRIPT);

system("rm -rf /opt/WiKID/var/update/update-$release-$build");
system("mv /opt/WiKID/var/update/pending-$release-$build /opt/WiKID/var/update/update-$release-$build");
unlink("/opt/WiKID/var/update/update-$release-$build/pid");

exit 0;
