#!/usr/bin/perl
## Network configuration script for the WiKID Authentication Server
##
## Copyright 2001-2011 WiKID Systems, Inc.
## License: WiKID Systems, Inc. All Rights Reserved.
##
## Basic setup function is to set the networking attributes to allow
## further configuration via the http interface.

## Configuration file that is read/written by this script to persist values 
## across invocations:

my @ints;
my $fakeip=10;
my @sys_intf=`netstat -i -a`;
foreach (@sys_intf) 
{
	chomp($_);
	if ($_ =~ /^Kernel/ || $_ =~ /^Iface/  || $_ =~  /^lo/) {next;}

	$_ =~ /(^\w+)/;
	my $ifname = $1;
	my $h = {
		"name" => $ifname,
		"ip" => "10.0.0.".$fakeip++,
		"netmask" => "255.255.255.0"
	};

	my $f = '/etc/network/interfaces';
	if (-f $f) { # debian/ubuntu systems
	
		open (F, $f);
		my $slurp = 0;
		my %h2 = ();
		while (<F>) {
			chomp;
			if (/^iface $ifname/) { $slurp = 1; } 
			if (/^iface / && !/^iface $ifname/) { $slurp = 0; } 
			next if $slurp==0; 
	
			if (/dhcp/) {
				print STDERR "\nWARNING: You are currently setup to use DHCP.  That is not recommended for a WiKID server.\n\n";
			}
				
			my @dhcp_inf=`ifconfig $ifname`;
			foreach my $dhcpline (@dhcp_inf) {
				if ($dhcpline =~ /inet addr:(\S+)\s+Bcast:(\S+)\s+Mask:(\S+)/) {
					$h2{'address'} = $1;
					$h2{'broadcast'} = $2;
					$h2{'netmask'} = $3;
				}
			}
			my @gw_info=`netstat -nr | grep $ifname`;
			foreach my $gwline (@gw_info) {
				if ($gwline =~ /^(default|0.0.0.0)\s+(\S+)/) {
					$h2{'gateway'} = $2;	
				}
			}
			$slurp = 0;

			my ($k,$v) = split /\s*(\w+?) (.+)/;
			$h2{lc($k)} = $v;
		}
		close (F);
		$h->{'ip'} = $h2{'address'};
		$h->{'netmask'} = $h2{'netmask'};
		$h->{'gateway'} = $h2{'gateway'};
		$h->{'nameservers'} = $h2{'dns-nameservers'}; # some DHCP servers provide this
	} else { # redhat-based systems
		$f = '/etc/sysconfig/network-scripts/ifcfg-'.$ifname;
		if (-f $f) {
			open (F, $f);
			my %h2 = ();
			while (<F>) {
				chomp;
				my ($k,$v) = split /=/;
				$h2{lc($k)} = $v;
			}
			close(F);
			$h->{'ip'} = $h2{'ipaddr'};
			$h->{'netmask'} = $h2{'netmask'};
			$serverParams{'default_gw'} = $h2{'gateway'};
		}
	}
	push @ints, $h;
}

#print STDERR "Found ".scalar(@ints)." interfaces\n";
foreach my $int (@ints) {
	my @line = ();
	foreach my $k (sort keys %$int) {
		my $v = $int->{$k};
		push @line, "$k=$v";
	}
	print join('|', @line) . "\n";
}
