#!/usr/bin/perl -w
use strict;
use lib '/opt/WiKID/lib';
use WiKIDUpdate;

if ($ARGV[0] and ($ARGV[0] eq '--help')) {
   print STDERR "Usage: $0 [--prune]\n";
   print STDERR "Lists checkpoints that are available for use.\n";
   print STDERR " --prune: Remove outdated checkpoints\n";
   exit 1;
}

opendir(DIR, "/opt/WiKID/var/update") or die "Could not upen update directory: $!\n";
while (my $dir = readdir(DIR)) {
   next unless $dir;
   next if ($dir =~ /^\./);
   next unless (-d "/opt/WiKID/var/update/$dir");
   my ($release, $build) = ($dir =~ /rollback-(.+)-(\d+)/);
   next unless ($release and $build);
   if (opendir(ROLLBACK, "/opt/WiKID/var/update/$dir")) {
      while (my $entry = readdir(ROLLBACK)) {
         next unless $entry;
         next if ($entry =~ /^\./);
         my ($new_release, $new_build);
         if (($new_release, $new_build) = ($entry =~ /archive-before-(.+)-(\d+)\.tgz/)) {
            my $time = localtime((stat "/opt/WiKID/var/update/$dir/$entry")[9]);
            my $outdated = 1;
            if ($WiKIDUpdate::release eq $new_release) {
               if ($WiKIDUpdate::build eq $new_build) {
                  $outdated = 0;
               }
            }
            print "[OUTDATED] " if $outdated;
            print "Release $new_release, build $new_build -> Release $release, build $build ($time)\n";
            if ($outdated) {
               if ($ARGV[0] and ($ARGV[0] eq '--prune')) {
                  if (system("rm -rf /opt/WiKID/var/update/$dir/back-from-$new_release-$new_build") == 0) {
                     print "   REMOVED RPMs.\n";
                  }
                  if (system("rm -f /opt/WiKID/var/update/$dir/archive-before-$new_release-$new_build.tgz") == 0) {
                     print "   REMOVED archive file.\n";
                  }
               }
            }
         } elsif ($entry =~ s/^archive-(\d+)\.tgz/$1/) {
            my $outdated = 1;
            my $time = localtime($entry);
            if ($WiKIDUpdate::release eq $release) {
               if ($WiKIDUpdate::build eq $build) {
                  $outdated = 0;
               }
            }
            print "[OUTDATED] " if $outdated;
            print "Release $release, build $build: Checkpoint $entry ($time)\n";
            if ($outdated) {
               if ($ARGV[0] and ($ARGV[0] eq '--prune')) {
                  if (system("rm -f /opt/WiKID/var/update/$dir/archive-$entry.tgz") == 0) {
                     print "   REMOVED archive file.\n";
                  }
               }
            }
         }
      }
      closedir(ROLLBACK);
   }
}
closedir(DIR);



