#!/usr/bin/perl -w
use strict;
use lib '/opt/WiKID/lib';
use WiKIDUpdate;

if ($ARGV[0] and ($ARGV[0] eq '--help')) {
   print STDERR "Usage: $0 [--prune]\n";
   print STDERR "Lists updates that have been dowloaded and their state.\n";
   print STDERR " --prune: Remove incomplete or outdated downloads\n";
   exit 1;
}

opendir(DIR, "/opt/WiKID/var/update") or die "Could not upen update directory: $!\n";
while (my $dir = readdir(DIR)) {
   next unless $dir;
   next if ($dir =~ /^\./);
   next unless (-d "/opt/WiKID/var/update/$dir");
   my (undef, $release, $build) = ($dir =~ /(pending|update)-(.+)-(\d+)/);
   next unless ($release and $build);
   unless (&WiKIDUpdate::verify_update_dir("/opt/WiKID/var/update/$dir")) {
      print "Outdated: Release $release, build $build\n";
      if ($ARGV[0] and ($ARGV[0] eq '--prune')) {
         if (system("rm -rf /opt/WiKID/var/update/$dir") == 0) {
            print "   REMOVED.\n";
         }
      }
      next;
   }
   if ($dir =~ /^pending-/) {
      if (open (PID, "/opt/WiKID/var/update/$dir/pid")) {
         my $pid = <PID>;
         chomp ($pid);
         system("ps $pid >/dev/null");
         if ($? == 0) {
            print "Downloading(pid=$pid): Release $release, build $build\n";
            next;
         }
      }
      print "Incomplete: Release $release, build $build\n";
      if ($ARGV[0] and ($ARGV[0] eq '--prune')) {
         if (system("rm -rf /opt/WiKID/var/update/$dir") == 0) {
            print "   REMOVED.\n";
         }
      }
   } elsif ($dir =~ /^update-/) {
      print "Ready: Release $release, build $build\n";
   }
}
closedir(DIR);

