#!/usr/bin/perl -w
use strict;
use lib '/opt/WiKID/lib';
use WiKIDUpdate;

sub usage() {
   print STDERR "Usage: $0 {timestamp | release build [currrelease currbuild]}\n";
   print STDERR "Installs a saved checkpoint, either by giving a\n";
   print STDERR "timestamp of a checkpoint of the current release/build\n";
   print STDERR "or by providing the previous release and build.\n";
   exit 1;
}

&usage() unless (($#ARGV == 1) or ($#ARGV == 0) or ($#ARGV == 3));
&usage() if ($ARGV[0] and ($ARGV[0] eq '--help'));

my $release = $ARGV[0];
my $build = $ARGV[1];
my $currrelease = $ARGV[2];
my $currbuild = $ARGV[3];
my $archive_file = '';

unless ($currrelease) {
   $currrelease = $WiKIDUpdate::release;
}
unless ($currbuild) {
   $currbuild = $WiKIDUpdate::build;
}

if ($release and $build) {
   unless (-d "/opt/WiKID/var/update/rollback-$release-$build/back-from-$currrelease-$currbuild") {
      die "Did not find data for a rollback to $release build $build from $currrelease build $currbuild\n";
   }

   my @remove_list = &::WiKIDUpdate::read_file("/opt/WiKID/var/update/rollback-$release-$build/back-from-$currrelease-$currbuild/downgrade_remove");
   if (@remove_list) {
      print "Removing RPMs...\n";
      if (&::WiKIDUpdate::remove_packages(@remove_list) == 0) {
         print STDERR "Could not remove one or more RPMs that needed to be removed.\n";
      }
   }

   print "Re-installing/removing/downgrading RPMs...\n";
   if (&::WiKIDUpdate::install_directory("/opt/WiKID/var/update/rollback-$release-$build/back-from-$currrelease-$currbuild", '--force') == 0) {
      print STDERR "Could not re-install or downgrade all necessary RPMs.\n";
   }

   if (-s "/opt/WiKID/var/update/rollback-$release-$build/back-from-$currrelease-$currbuild/downgrade_script") {
      print "Executing downgrade script...\n";
      unless (system ('bash', "/opt/WiKID/var/update/rollback-$release-$build/back-from-$currrelease-$currbuild/downgrade_script") == 0) {
         print STDERR "There was a failure running the downgrade script...\n";
      }
   }

   # Extract the archive that was created before the upgrade
   $archive_file = "/opt/WiKID/var/update/rollback-$release-$build/archive-before-$currrelease-$currbuild.tgz";
} else {
   # Must have specified just a timestamp 
   $archive_file = "/opt/WiKID/var/update/rollback-$currrelease-$currbuild/archive-$release.tgz";
   unless (-f $archive_file) {
      print STDERR "Checkpoint '$release' for current release/build not found\n";
      exit 1;
   }
}

# Extract rollback archive file
if (-f $archive_file) {
   chdir('/');
   print "Extracting the rollback archive...\n";
   unless (system('tar', '-xzpf', $archive_file) == 0) {
      print STDERR "Warning: Checkpoint archive file extraction had errors\n";
   }
} else {
   print STDERR "Warning: Checkpoint archive file does not exist: $archive_file\n";
}

# Re-apply system configuration
print "\nRe-configuring your system...\n";
system("/opt/WiKID/sbin/reconfig");
print "Done.\n\n";

unless ($release and $build) {
   print "Rollback to checkpoint '$release' is complete\n";
   exit 0;
}

&::WiKIDUpdate::record_release_build($release, $build);

system('rm', '-rf', "/opt/WiKID/var/update/rollback-$release-$build/back-from-$currrelease-$currbuild");

print "Rollback to $release build $build is complete.\n"


